# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hyperlane.warp.v1 import types_pb2 as hyperlane_dot_warp_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fhyperlane/warp/v1/genesis.proto\x12\x11hyperlane.warp.v1\x1a\x1dhyperlane/warp/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\xde\x01\n\x0cGenesisState\x12\x37\n\x06params\x18\x01 \x01(\x0b\x32\x19.hyperlane.warp.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12\x39\n\x06tokens\x18\x02 \x03(\x0b\x32\x1b.hyperlane.warp.v1.HypTokenB\x04\xc8\xde\x1f\x00R\x06tokens\x12Z\n\x0eremote_routers\x18\x03 \x03(\x0b\x32-.hyperlane.warp.v1.GenesisRemoteRouterWrapperB\x04\xc8\xde\x1f\x00R\rremoteRouters\"\x83\x01\n\x1aGenesisRemoteRouterWrapper\x12\x19\n\x08token_id\x18\x01 \x01(\x04R\x07tokenId\x12J\n\rremote_router\x18\x02 \x01(\x0b\x32\x1f.hyperlane.warp.v1.RemoteRouterB\x04\xc8\xde\x1f\x00R\x0cremoteRouterB\xc5\x01\n\x15\x63om.hyperlane.warp.v1B\x0cGenesisProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\014GenesisProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['tokens']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['tokens']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['remote_routers']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['remote_routers']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISREMOTEROUTERWRAPPER'].fields_by_name['remote_router']._loaded_options = None
  _globals['_GENESISREMOTEROUTERWRAPPER'].fields_by_name['remote_router']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=108
  _globals['_GENESISSTATE']._serialized_end=330
  _globals['_GENESISREMOTEROUTERWRAPPER']._serialized_start=333
  _globals['_GENESISREMOTEROUTERWRAPPER']._serialized_end=464
# @@protoc_insertion_point(module_scope)
