# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/downtimedetector/v1beta1/downtime_duration.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:injective/downtimedetector/v1beta1/downtime_duration.proto\x12\"injective.downtimedetector.v1beta1\x1a\x14gogoproto/gogo.proto*\xfa\x06\n\x08\x44owntime\x12\"\n\x0c\x44URATION_30S\x10\x00\x1a\x10\x8a\x9d \x0c\x44URATION_30S\x12 \n\x0b\x44URATION_1M\x10\x01\x1a\x0f\x8a\x9d \x0b\x44URATION_1M\x12 \n\x0b\x44URATION_2M\x10\x02\x1a\x0f\x8a\x9d \x0b\x44URATION_2M\x12 \n\x0b\x44URATION_3M\x10\x03\x1a\x0f\x8a\x9d \x0b\x44URATION_3M\x12 \n\x0b\x44URATION_4M\x10\x04\x1a\x0f\x8a\x9d \x0b\x44URATION_4M\x12 \n\x0b\x44URATION_5M\x10\x05\x1a\x0f\x8a\x9d \x0b\x44URATION_5M\x12\"\n\x0c\x44URATION_10M\x10\x06\x1a\x10\x8a\x9d \x0c\x44URATION_10M\x12\"\n\x0c\x44URATION_20M\x10\x07\x1a\x10\x8a\x9d \x0c\x44URATION_20M\x12\"\n\x0c\x44URATION_30M\x10\x08\x1a\x10\x8a\x9d \x0c\x44URATION_30M\x12\"\n\x0c\x44URATION_40M\x10\t\x1a\x10\x8a\x9d \x0c\x44URATION_40M\x12\"\n\x0c\x44URATION_50M\x10\n\x1a\x10\x8a\x9d \x0c\x44URATION_50M\x12 \n\x0b\x44URATION_1H\x10\x0b\x1a\x0f\x8a\x9d \x0b\x44URATION_1H\x12$\n\rDURATION_1_5H\x10\x0c\x1a\x11\x8a\x9d \rDURATION_1_5H\x12 \n\x0b\x44URATION_2H\x10\r\x1a\x0f\x8a\x9d \x0b\x44URATION_2H\x12$\n\rDURATION_2_5H\x10\x0e\x1a\x11\x8a\x9d \rDURATION_2_5H\x12 \n\x0b\x44URATION_3H\x10\x0f\x1a\x0f\x8a\x9d \x0b\x44URATION_3H\x12 \n\x0b\x44URATION_4H\x10\x10\x1a\x0f\x8a\x9d \x0b\x44URATION_4H\x12 \n\x0b\x44URATION_5H\x10\x11\x1a\x0f\x8a\x9d \x0b\x44URATION_5H\x12 \n\x0b\x44URATION_6H\x10\x12\x1a\x0f\x8a\x9d \x0b\x44URATION_6H\x12 \n\x0b\x44URATION_9H\x10\x13\x1a\x0f\x8a\x9d \x0b\x44URATION_9H\x12\"\n\x0c\x44URATION_12H\x10\x14\x1a\x10\x8a\x9d \x0c\x44URATION_12H\x12\"\n\x0c\x44URATION_18H\x10\x15\x1a\x10\x8a\x9d \x0c\x44URATION_18H\x12\"\n\x0c\x44URATION_24H\x10\x16\x1a\x10\x8a\x9d \x0c\x44URATION_24H\x12\"\n\x0c\x44URATION_36H\x10\x17\x1a\x10\x8a\x9d \x0c\x44URATION_36H\x12\"\n\x0c\x44URATION_48H\x10\x18\x1a\x10\x8a\x9d \x0c\x44URATION_48HB\xc2\x02\n&com.injective.downtimedetector.v1beta1B\x15\x44owntimeDurationProtoP\x01ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\xa2\x02\x03IDX\xaa\x02\"Injective.Downtimedetector.V1beta1\xca\x02\"Injective\\Downtimedetector\\V1beta1\xe2\x02.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\xea\x02$Injective::Downtimedetector::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.downtimedetector.v1beta1.downtime_duration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.injective.downtimedetector.v1beta1B\025DowntimeDurationProtoP\001ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\242\002\003IDX\252\002\"Injective.Downtimedetector.V1beta1\312\002\"Injective\\Downtimedetector\\V1beta1\342\002.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\352\002$Injective::Downtimedetector::V1beta1'
  _globals['_DOWNTIME'].values_by_name["DURATION_30S"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_30S"]._serialized_options = b'\212\235 \014DURATION_30S'
  _globals['_DOWNTIME'].values_by_name["DURATION_1M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_1M"]._serialized_options = b'\212\235 \013DURATION_1M'
  _globals['_DOWNTIME'].values_by_name["DURATION_2M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_2M"]._serialized_options = b'\212\235 \013DURATION_2M'
  _globals['_DOWNTIME'].values_by_name["DURATION_3M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_3M"]._serialized_options = b'\212\235 \013DURATION_3M'
  _globals['_DOWNTIME'].values_by_name["DURATION_4M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_4M"]._serialized_options = b'\212\235 \013DURATION_4M'
  _globals['_DOWNTIME'].values_by_name["DURATION_5M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_5M"]._serialized_options = b'\212\235 \013DURATION_5M'
  _globals['_DOWNTIME'].values_by_name["DURATION_10M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_10M"]._serialized_options = b'\212\235 \014DURATION_10M'
  _globals['_DOWNTIME'].values_by_name["DURATION_20M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_20M"]._serialized_options = b'\212\235 \014DURATION_20M'
  _globals['_DOWNTIME'].values_by_name["DURATION_30M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_30M"]._serialized_options = b'\212\235 \014DURATION_30M'
  _globals['_DOWNTIME'].values_by_name["DURATION_40M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_40M"]._serialized_options = b'\212\235 \014DURATION_40M'
  _globals['_DOWNTIME'].values_by_name["DURATION_50M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_50M"]._serialized_options = b'\212\235 \014DURATION_50M'
  _globals['_DOWNTIME'].values_by_name["DURATION_1H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_1H"]._serialized_options = b'\212\235 \013DURATION_1H'
  _globals['_DOWNTIME'].values_by_name["DURATION_1_5H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_1_5H"]._serialized_options = b'\212\235 \rDURATION_1_5H'
  _globals['_DOWNTIME'].values_by_name["DURATION_2H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_2H"]._serialized_options = b'\212\235 \013DURATION_2H'
  _globals['_DOWNTIME'].values_by_name["DURATION_2_5H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_2_5H"]._serialized_options = b'\212\235 \rDURATION_2_5H'
  _globals['_DOWNTIME'].values_by_name["DURATION_3H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_3H"]._serialized_options = b'\212\235 \013DURATION_3H'
  _globals['_DOWNTIME'].values_by_name["DURATION_4H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_4H"]._serialized_options = b'\212\235 \013DURATION_4H'
  _globals['_DOWNTIME'].values_by_name["DURATION_5H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_5H"]._serialized_options = b'\212\235 \013DURATION_5H'
  _globals['_DOWNTIME'].values_by_name["DURATION_6H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_6H"]._serialized_options = b'\212\235 \013DURATION_6H'
  _globals['_DOWNTIME'].values_by_name["DURATION_9H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_9H"]._serialized_options = b'\212\235 \013DURATION_9H'
  _globals['_DOWNTIME'].values_by_name["DURATION_12H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_12H"]._serialized_options = b'\212\235 \014DURATION_12H'
  _globals['_DOWNTIME'].values_by_name["DURATION_18H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_18H"]._serialized_options = b'\212\235 \014DURATION_18H'
  _globals['_DOWNTIME'].values_by_name["DURATION_24H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_24H"]._serialized_options = b'\212\235 \014DURATION_24H'
  _globals['_DOWNTIME'].values_by_name["DURATION_36H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_36H"]._serialized_options = b'\212\235 \014DURATION_36H'
  _globals['_DOWNTIME'].values_by_name["DURATION_48H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_48H"]._serialized_options = b'\212\235 \014DURATION_48H'
  _globals['_DOWNTIME']._serialized_start=121
  _globals['_DOWNTIME']._serialized_end=1011
# @@protoc_insertion_point(module_scope)
