# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,hyperlane/core/post_dispatch/v1/events.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a\x14gogoproto/gogo.proto\"\x89\x02\n\x19\x45ventCreateMerkleTreeHook\x12r\n\x13merkle_tree_hook_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x10merkleTreeHookId\x12\x62\n\nmailbox_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner\"\x85\x02\n\x15\x45ventInsertedIntoTree\x12\x62\n\nmessage_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageId\x12\x14\n\x05index\x18\x02 \x01(\rR\x05index\x12r\n\x13merkle_tree_hook_id\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x10merkleTreeHookId\"\xac\x02\n\x0f\x45ventGasPayment\x12\x62\n\nmessage_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageId\x12 \n\x0b\x64\x65stination\x18\x02 \x01(\rR\x0b\x64\x65stination\x12\x1d\n\ngas_amount\x18\x03 \x01(\tR\tgasAmount\x12\x18\n\x07payment\x18\x04 \x01(\tR\x07payment\x12Z\n\x06igp_id\x18\x05 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\"\x92\x01\n\x13\x45ventCreateNoopHook\x12\x65\n\x0cnoop_hook_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\nnoopHookId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\"\x98\x01\n\x0e\x45ventCreateIgp\x12Z\n\x06igp_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x14\n\x05\x64\x65nom\x18\x03 \x01(\tR\x05\x64\x65nom\"\xcb\x01\n\x0b\x45ventSetIgp\x12Z\n\x06igp_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x1b\n\tnew_owner\x18\x03 \x01(\tR\x08newOwner\x12-\n\x12renounce_ownership\x18\x04 \x01(\x08R\x11renounceOwnership\"\x82\x03\n\x1c\x45ventSetDestinationGasConfig\x12Z\n\x06igp_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12#\n\rremote_domain\x18\x04 \x01(\rR\x0cremoteDomain\x12@\n\x0cgas_overhead\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x0bgasOverhead\x12:\n\tgas_price\x18\x06 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasPrice\x12M\n\x13token_exchange_rate\x18\x07 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x11tokenExchangeRate\"\x99\x01\n\rEventClaimIgp\x12Z\n\x06igp_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x16\n\x06\x61mount\x18\x03 \x01(\tR\x06\x61mountB\x98\x02\n#com.hyperlane.core.post_dispatch.v1B\x0b\x45ventsProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\013EventsProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_EVENTCREATEMERKLETREEHOOK'].fields_by_name['merkle_tree_hook_id']._loaded_options = None
  _globals['_EVENTCREATEMERKLETREEHOOK'].fields_by_name['merkle_tree_hook_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEMERKLETREEHOOK'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_EVENTCREATEMERKLETREEHOOK'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTINSERTEDINTOTREE'].fields_by_name['message_id']._loaded_options = None
  _globals['_EVENTINSERTEDINTOTREE'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTINSERTEDINTOTREE'].fields_by_name['merkle_tree_hook_id']._loaded_options = None
  _globals['_EVENTINSERTEDINTOTREE'].fields_by_name['merkle_tree_hook_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTGASPAYMENT'].fields_by_name['message_id']._loaded_options = None
  _globals['_EVENTGASPAYMENT'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTGASPAYMENT'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTGASPAYMENT'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATENOOPHOOK'].fields_by_name['noop_hook_id']._loaded_options = None
  _globals['_EVENTCREATENOOPHOOK'].fields_by_name['noop_hook_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEIGP'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTCREATEIGP'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETIGP'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTSETIGP'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['gas_overhead']._loaded_options = None
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['gas_overhead']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['gas_price']._loaded_options = None
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['gas_price']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['token_exchange_rate']._loaded_options = None
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['token_exchange_rate']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTCLAIMIGP'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTCLAIMIGP'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEMERKLETREEHOOK']._serialized_start=104
  _globals['_EVENTCREATEMERKLETREEHOOK']._serialized_end=369
  _globals['_EVENTINSERTEDINTOTREE']._serialized_start=372
  _globals['_EVENTINSERTEDINTOTREE']._serialized_end=633
  _globals['_EVENTGASPAYMENT']._serialized_start=636
  _globals['_EVENTGASPAYMENT']._serialized_end=936
  _globals['_EVENTCREATENOOPHOOK']._serialized_start=939
  _globals['_EVENTCREATENOOPHOOK']._serialized_end=1085
  _globals['_EVENTCREATEIGP']._serialized_start=1088
  _globals['_EVENTCREATEIGP']._serialized_end=1240
  _globals['_EVENTSETIGP']._serialized_start=1243
  _globals['_EVENTSETIGP']._serialized_end=1446
  _globals['_EVENTSETDESTINATIONGASCONFIG']._serialized_start=1449
  _globals['_EVENTSETDESTINATIONGASCONFIG']._serialized_end=1835
  _globals['_EVENTCLAIMIGP']._serialized_start=1838
  _globals['_EVENTCLAIMIGP']._serialized_end=1991
# @@protoc_insertion_point(module_scope)
