# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hyperlane.core.post_dispatch.v1 import types_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-hyperlane/core/post_dispatch/v1/genesis.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a+hyperlane/core/post_dispatch/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\x87\x03\n\x0cGenesisState\x12Q\n\x04igps\x18\x01 \x03(\x0b\x32\x37.hyperlane.core.post_dispatch.v1.InterchainGasPaymasterB\x04\xc8\xde\x1f\x00R\x04igps\x12q\n\x0figp_gas_configs\x18\x02 \x03(\x0b\x32\x43.hyperlane.core.post_dispatch.v1.GenesisDestinationGasConfigWrapperB\x04\xc8\xde\x1f\x00R\rigpGasConfigs\x12\x61\n\x11merkle_tree_hooks\x18\x03 \x03(\x0b\x32/.hyperlane.core.post_dispatch.v1.MerkleTreeHookB\x04\xc8\xde\x1f\x00R\x0fmerkleTreeHooks\x12N\n\nnoop_hooks\x18\x04 \x03(\x0b\x32).hyperlane.core.post_dispatch.v1.NoopHookB\x04\xc8\xde\x1f\x00R\tnoopHooks\"\xed\x01\n\"GenesisDestinationGasConfigWrapper\x12#\n\rremote_domain\x18\x01 \x01(\rR\x0cremoteDomain\x12I\n\ngas_oracle\x18\x02 \x01(\x0b\x32*.hyperlane.core.post_dispatch.v1.GasOracleR\tgasOracle\x12@\n\x0cgas_overhead\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x0bgasOverhead\x12\x15\n\x06igp_id\x18\x04 \x01(\x04R\x05igpIdB\x99\x02\n#com.hyperlane.core.post_dispatch.v1B\x0cGenesisProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\014GenesisProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_GENESISSTATE'].fields_by_name['igps']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['igps']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['igp_gas_configs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['igp_gas_configs']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['merkle_tree_hooks']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['merkle_tree_hooks']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['noop_hooks']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['noop_hooks']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISDESTINATIONGASCONFIGWRAPPER'].fields_by_name['gas_overhead']._loaded_options = None
  _globals['_GENESISDESTINATIONGASCONFIGWRAPPER'].fields_by_name['gas_overhead']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_GENESISSTATE']._serialized_start=150
  _globals['_GENESISSTATE']._serialized_end=541
  _globals['_GENESISDESTINATIONGASCONFIGWRAPPER']._serialized_start=544
  _globals['_GENESISDESTINATIONGASCONFIGWRAPPER']._serialized_end=781
# @@protoc_insertion_point(module_scope)
