# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_rfqrpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65xchange/injective_rfqrpc.proto\x12\x10injective_rfqrpc\"L\n\x0eRequestRequest\x12:\n\x07request\x18\x01 \x01(\x0b\x32 .injective_rfqrpc.RFQRequestTypeR\x07request\"\x91\x03\n\x0eRFQRequestType\x12\x15\n\x06rfq_id\x18\x01 \x01(\x04R\x05rfqId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12\x16\n\x06margin\x18\x04 \x01(\tR\x06margin\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0bworst_price\x18\x06 \x01(\tR\nworstPrice\x12\'\n\x0frequest_address\x18\x07 \x01(\tR\x0erequestAddress\x12\x16\n\x06\x65xpiry\x18\x08 \x01(\x04R\x06\x65xpiry\x12\x16\n\x06status\x18\t \x01(\tR\x06status\x12\x1d\n\ncreated_at\x18\n \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0b \x01(\x12R\tupdatedAt\x12)\n\x10transaction_time\x18\x0c \x01(\x04R\x0ftransactionTime\x12\x16\n\x06height\x18\r \x01(\x04R\x06height\")\n\x0fRequestResponse\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"5\n\x14StreamRequestRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"~\n\x15StreamRequestResponse\x12:\n\x07request\x18\x01 \x01(\x0b\x32 .injective_rfqrpc.RFQRequestTypeR\x07request\x12)\n\x10stream_operation\x18\x02 \x01(\tR\x0fstreamOperation\"D\n\x0cQuoteRequest\x12\x34\n\x05quote\x18\x01 \x01(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x05quote\"\x95\x04\n\x0cRFQQuoteType\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\tR\x07\x63hainId\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\x15\n\x06rfq_id\x18\x04 \x01(\x04R\x05rfqId\x12\'\n\x0ftaker_direction\x18\x05 \x01(\tR\x0etakerDirection\x12\x16\n\x06margin\x18\x06 \x01(\tR\x06margin\x12\x1a\n\x08quantity\x18\x07 \x01(\tR\x08quantity\x12\x14\n\x05price\x18\x08 \x01(\tR\x05price\x12\x16\n\x06\x65xpiry\x18\t \x01(\x04R\x06\x65xpiry\x12\x14\n\x05maker\x18\n \x01(\tR\x05maker\x12\x14\n\x05taker\x18\x0b \x01(\tR\x05taker\x12\x1c\n\tsignature\x18\x0c \x01(\tR\tsignature\x12\x16\n\x06status\x18\r \x01(\tR\x06status\x12\x1d\n\ncreated_at\x18\x0e \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0f \x01(\x12R\tupdatedAt\x12\x16\n\x06height\x18\x10 \x01(\x04R\x06height\x12\x1d\n\nevent_time\x18\x11 \x01(\x04R\teventTime\x12)\n\x10transaction_time\x18\x12 \x01(\x04R\x0ftransactionTime\"\'\n\rQuoteResponse\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"2\n\x12StreamQuoteRequest\x12\x1c\n\taddresses\x18\x01 \x03(\tR\taddresses\"v\n\x13StreamQuoteResponse\x12\x34\n\x05quote\x18\x01 \x01(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x05quote\x12)\n\x10stream_operation\x18\x02 \x01(\tR\x0fstreamOperation\"\x18\n\x16GetOpenRequestsRequest\"W\n\x17GetOpenRequestsResponse\x12<\n\x08requests\x18\x01 \x03(\x0b\x32 .injective_rfqrpc.RFQRequestTypeR\x08requests\"\x19\n\x17GetPendingQuotesRequest\"R\n\x18GetPendingQuotesResponse\x12\x36\n\x06quotes\x18\x01 \x03(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x06quotes\"_\n\x15ListSettlementRequest\x12\x1c\n\taddresses\x18\x01 \x03(\tR\taddresses\x12\x12\n\x04skip\x18\x02 \x01(\x12R\x04skip\x12\x14\n\x05limit\x18\x03 \x01(\x12R\x05limit\"u\n\x16ListSettlementResponse\x12\x45\n\x0bsettlements\x18\x01 \x03(\x0b\x32#.injective_rfqrpc.RFQSettlementTypeR\x0bsettlements\x12\x14\n\x05total\x18\x02 \x01(\x12R\x05total\"\xa2\x04\n\x11RFQSettlementType\x12\x15\n\x06rfq_id\x18\x01 \x01(\x04R\x05rfqId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x14\n\x05taker\x18\x03 \x01(\tR\x05taker\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x16\n\x06margin\x18\x05 \x01(\tR\x06margin\x12\x1a\n\x08quantity\x18\x06 \x01(\tR\x08quantity\x12\x1f\n\x0bworst_price\x18\x07 \x01(\tR\nworstPrice\x12Z\n\x0funfilled_action\x18\x08 \x01(\x0b\x32\x31.injective_rfqrpc.RFQSettlementUnfilledActionTypeR\x0eunfilledAction\x12+\n\x11\x66\x61llback_quantity\x18\t \x01(\tR\x10\x66\x61llbackQuantity\x12\'\n\x0f\x66\x61llback_margin\x18\n \x01(\tR\x0e\x66\x61llbackMargin\x12)\n\x10transaction_time\x18\x0b \x01(\x04R\x0ftransactionTime\x12\x1d\n\ncreated_at\x18\x0c \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\r \x01(\x12R\tupdatedAt\x12\x1d\n\nevent_time\x18\x0e \x01(\x04R\teventTime\x12\x16\n\x06height\x18\x0f \x01(\x04R\x06height\"\xb0\x01\n\x1fRFQSettlementUnfilledActionType\x12\x44\n\x05limit\x18\x01 \x01(\x0b\x32..injective_rfqrpc.RFQSettlementLimitActionTypeR\x05limit\x12G\n\x06market\x18\x02 \x01(\x0b\x32/.injective_rfqrpc.RFQSettlementMarketActionTypeR\x06market\"4\n\x1cRFQSettlementLimitActionType\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\"\x1f\n\x1dRFQSettlementMarketActionType\"7\n\x17StreamSettlementRequest\x12\x1c\n\taddresses\x18\x01 \x03(\tR\taddresses\"\x8a\x01\n\x18StreamSettlementResponse\x12\x43\n\nsettlement\x18\x01 \x01(\x0b\x32#.injective_rfqrpc.RFQSettlementTypeR\nsettlement\x12)\n\x10stream_operation\x18\x02 \x01(\tR\x0fstreamOperation\"\x82\x01\n\x1bTakerStreamStreamingRequest\x12!\n\x0cmessage_type\x18\x01 \x01(\tR\x0bmessageType\x12@\n\x07request\x18\x02 \x01(\x0b\x32&.injective_rfqrpc.CreateRFQRequestTypeR\x07request\"\xee\x02\n\x14\x43reateRFQRequestType\x12\x15\n\x06rfq_id\x18\x01 \x01(\x04R\x05rfqId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12\x16\n\x06margin\x18\x04 \x01(\tR\x06margin\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0bworst_price\x18\x06 \x01(\tR\nworstPrice\x12\x16\n\x06\x65xpiry\x18\x07 \x01(\x04R\x06\x65xpiry\x12\x16\n\x06status\x18\x08 \x01(\tR\x06status\x12\x1d\n\ncreated_at\x18\t \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\n \x01(\x12R\tupdatedAt\x12)\n\x10transaction_time\x18\x0b \x01(\x04R\x0ftransactionTime\x12\x16\n\x06height\x18\x0c \x01(\x04R\x06height\"\xe1\x01\n\x13TakerStreamResponse\x12!\n\x0cmessage_type\x18\x01 \x01(\tR\x0bmessageType\x12\x34\n\x05quote\x18\x02 \x01(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x05quote\x12<\n\x0brequest_ack\x18\x03 \x01(\x0b\x32\x1b.injective_rfqrpc.StreamAckR\nrequestAck\x12\x33\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x1d.injective_rfqrpc.StreamErrorR\x05\x65rror\":\n\tStreamAck\x12\x15\n\x06rfq_id\x18\x01 \x01(\x04R\x05rfqId\x12\x16\n\x06status\x18\x02 \x01(\tR\x06status\"<\n\x0bStreamError\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x19\n\x08message_\x18\x02 \x01(\tR\x07message\"v\n\x1bMakerStreamStreamingRequest\x12!\n\x0cmessage_type\x18\x01 \x01(\tR\x0bmessageType\x12\x34\n\x05quote\x18\x02 \x01(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x05quote\"\xe3\x01\n\x13MakerStreamResponse\x12!\n\x0cmessage_type\x18\x01 \x01(\tR\x0bmessageType\x12:\n\x07request\x18\x02 \x01(\x0b\x32 .injective_rfqrpc.RFQRequestTypeR\x07request\x12\x38\n\tquote_ack\x18\x03 \x01(\x0b\x32\x1b.injective_rfqrpc.StreamAckR\x08quoteAck\x12\x33\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x1d.injective_rfqrpc.StreamErrorR\x05\x65rror2\xe4\x07\n\x0fInjectiveRFQRPC\x12N\n\x07Request\x12 .injective_rfqrpc.RequestRequest\x1a!.injective_rfqrpc.RequestResponse\x12\x62\n\rStreamRequest\x12&.injective_rfqrpc.StreamRequestRequest\x1a\'.injective_rfqrpc.StreamRequestResponse0\x01\x12H\n\x05Quote\x12\x1e.injective_rfqrpc.QuoteRequest\x1a\x1f.injective_rfqrpc.QuoteResponse\x12\\\n\x0bStreamQuote\x12$.injective_rfqrpc.StreamQuoteRequest\x1a%.injective_rfqrpc.StreamQuoteResponse0\x01\x12\x66\n\x0fGetOpenRequests\x12(.injective_rfqrpc.GetOpenRequestsRequest\x1a).injective_rfqrpc.GetOpenRequestsResponse\x12i\n\x10GetPendingQuotes\x12).injective_rfqrpc.GetPendingQuotesRequest\x1a*.injective_rfqrpc.GetPendingQuotesResponse\x12\x63\n\x0eListSettlement\x12\'.injective_rfqrpc.ListSettlementRequest\x1a(.injective_rfqrpc.ListSettlementResponse\x12k\n\x10StreamSettlement\x12).injective_rfqrpc.StreamSettlementRequest\x1a*.injective_rfqrpc.StreamSettlementResponse0\x01\x12g\n\x0bTakerStream\x12-.injective_rfqrpc.TakerStreamStreamingRequest\x1a%.injective_rfqrpc.TakerStreamResponse(\x01\x30\x01\x12g\n\x0bMakerStream\x12-.injective_rfqrpc.MakerStreamStreamingRequest\x1a%.injective_rfqrpc.MakerStreamResponse(\x01\x30\x01\x42\x9d\x01\n\x14\x63om.injective_rfqrpcB\x14InjectiveRfqrpcProtoP\x01Z\x13/injective_rfqrpcpb\xa2\x02\x03IXX\xaa\x02\x0fInjectiveRfqrpc\xca\x02\x0fInjectiveRfqrpc\xe2\x02\x1bInjectiveRfqrpc\\GPBMetadata\xea\x02\x0fInjectiveRfqrpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_rfqrpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective_rfqrpcB\024InjectiveRfqrpcProtoP\001Z\023/injective_rfqrpcpb\242\002\003IXX\252\002\017InjectiveRfqrpc\312\002\017InjectiveRfqrpc\342\002\033InjectiveRfqrpc\\GPBMetadata\352\002\017InjectiveRfqrpc'
  _globals['_REQUESTREQUEST']._serialized_start=53
  _globals['_REQUESTREQUEST']._serialized_end=129
  _globals['_RFQREQUESTTYPE']._serialized_start=132
  _globals['_RFQREQUESTTYPE']._serialized_end=533
  _globals['_REQUESTRESPONSE']._serialized_start=535
  _globals['_REQUESTRESPONSE']._serialized_end=576
  _globals['_STREAMREQUESTREQUEST']._serialized_start=578
  _globals['_STREAMREQUESTREQUEST']._serialized_end=631
  _globals['_STREAMREQUESTRESPONSE']._serialized_start=633
  _globals['_STREAMREQUESTRESPONSE']._serialized_end=759
  _globals['_QUOTEREQUEST']._serialized_start=761
  _globals['_QUOTEREQUEST']._serialized_end=829
  _globals['_RFQQUOTETYPE']._serialized_start=832
  _globals['_RFQQUOTETYPE']._serialized_end=1365
  _globals['_QUOTERESPONSE']._serialized_start=1367
  _globals['_QUOTERESPONSE']._serialized_end=1406
  _globals['_STREAMQUOTEREQUEST']._serialized_start=1408
  _globals['_STREAMQUOTEREQUEST']._serialized_end=1458
  _globals['_STREAMQUOTERESPONSE']._serialized_start=1460
  _globals['_STREAMQUOTERESPONSE']._serialized_end=1578
  _globals['_GETOPENREQUESTSREQUEST']._serialized_start=1580
  _globals['_GETOPENREQUESTSREQUEST']._serialized_end=1604
  _globals['_GETOPENREQUESTSRESPONSE']._serialized_start=1606
  _globals['_GETOPENREQUESTSRESPONSE']._serialized_end=1693
  _globals['_GETPENDINGQUOTESREQUEST']._serialized_start=1695
  _globals['_GETPENDINGQUOTESREQUEST']._serialized_end=1720
  _globals['_GETPENDINGQUOTESRESPONSE']._serialized_start=1722
  _globals['_GETPENDINGQUOTESRESPONSE']._serialized_end=1804
  _globals['_LISTSETTLEMENTREQUEST']._serialized_start=1806
  _globals['_LISTSETTLEMENTREQUEST']._serialized_end=1901
  _globals['_LISTSETTLEMENTRESPONSE']._serialized_start=1903
  _globals['_LISTSETTLEMENTRESPONSE']._serialized_end=2020
  _globals['_RFQSETTLEMENTTYPE']._serialized_start=2023
  _globals['_RFQSETTLEMENTTYPE']._serialized_end=2569
  _globals['_RFQSETTLEMENTUNFILLEDACTIONTYPE']._serialized_start=2572
  _globals['_RFQSETTLEMENTUNFILLEDACTIONTYPE']._serialized_end=2748
  _globals['_RFQSETTLEMENTLIMITACTIONTYPE']._serialized_start=2750
  _globals['_RFQSETTLEMENTLIMITACTIONTYPE']._serialized_end=2802
  _globals['_RFQSETTLEMENTMARKETACTIONTYPE']._serialized_start=2804
  _globals['_RFQSETTLEMENTMARKETACTIONTYPE']._serialized_end=2835
  _globals['_STREAMSETTLEMENTREQUEST']._serialized_start=2837
  _globals['_STREAMSETTLEMENTREQUEST']._serialized_end=2892
  _globals['_STREAMSETTLEMENTRESPONSE']._serialized_start=2895
  _globals['_STREAMSETTLEMENTRESPONSE']._serialized_end=3033
  _globals['_TAKERSTREAMSTREAMINGREQUEST']._serialized_start=3036
  _globals['_TAKERSTREAMSTREAMINGREQUEST']._serialized_end=3166
  _globals['_CREATERFQREQUESTTYPE']._serialized_start=3169
  _globals['_CREATERFQREQUESTTYPE']._serialized_end=3535
  _globals['_TAKERSTREAMRESPONSE']._serialized_start=3538
  _globals['_TAKERSTREAMRESPONSE']._serialized_end=3763
  _globals['_STREAMACK']._serialized_start=3765
  _globals['_STREAMACK']._serialized_end=3823
  _globals['_STREAMERROR']._serialized_start=3825
  _globals['_STREAMERROR']._serialized_end=3885
  _globals['_MAKERSTREAMSTREAMINGREQUEST']._serialized_start=3887
  _globals['_MAKERSTREAMSTREAMINGREQUEST']._serialized_end=4005
  _globals['_MAKERSTREAMRESPONSE']._serialized_start=4008
  _globals['_MAKERSTREAMRESPONSE']._serialized_end=4235
  _globals['_INJECTIVERFQRPC']._serialized_start=4238
  _globals['_INJECTIVERFQRPC']._serialized_end=5234
# @@protoc_insertion_point(module_scope)
