# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from hyperlane.core.interchain_security.v1 import types_pb2 as hyperlane_dot_core_dot_interchain__security_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.hyperlane/core/interchain_security/v1/tx.proto\x12%hyperlane.core.interchain_security.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a\x31hyperlane/core/interchain_security/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\xb4\x01\n\x1dMsgCreateMessageIdMultisigIsm\x12\x18\n\x07\x63reator\x18\x01 \x01(\tR\x07\x63reator\x12\x1e\n\nvalidators\x18\x02 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold:;\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0**hyperlane/v1/MsgCreateMessageIdMultisigIsm\"|\n%MsgCreateMessageIdMultisigIsmResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xb6\x01\n\x1eMsgCreateMerkleRootMultisigIsm\x12\x18\n\x07\x63reator\x18\x01 \x01(\tR\x07\x63reator\x12\x1e\n\nvalidators\x18\x02 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold:<\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0*+hyperlane/v1/MsgCreateMerkleRootMultisigIsm\"}\n&MsgCreateMerkleRootMultisigIsmResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\\\n\x10MsgCreateNoopIsm\x12\x18\n\x07\x63reator\x18\x01 \x01(\tR\x07\x63reator:.\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0*\x1dhyperlane/v1/MsgCreateNoopIsm\"o\n\x18MsgCreateNoopIsmResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xaf\x02\n\x14MsgAnnounceValidator\x12\x1c\n\tvalidator\x18\x01 \x01(\tR\tvalidator\x12)\n\x10storage_location\x18\x02 \x01(\tR\x0fstorageLocation\x12\x1c\n\tsignature\x18\x03 \x01(\tR\tsignature\x12\x62\n\nmailbox_id\x18\x04 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x18\n\x07\x63reator\x18\x05 \x01(\tR\x07\x63reator:2\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0*!hyperlane/v1/MsgAnnounceValidator\"\x1e\n\x1cMsgAnnounceValidatorResponse\"\xae\x01\n\x13MsgCreateRoutingIsm\x12\x18\n\x07\x63reator\x18\x01 \x01(\tR\x07\x63reator\x12J\n\x06routes\x18\x02 \x03(\x0b\x32,.hyperlane.core.interchain_security.v1.RouteB\x04\xc8\xde\x1f\x00R\x06routes:1\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0* hyperlane/v1/MsgCreateRoutingIsm\"r\n\x1bMsgCreateRoutingIsmResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\x9b\x02\n\x16MsgSetRoutingIsmDomain\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12H\n\x05route\x18\x02 \x01(\x0b\x32,.hyperlane.core.interchain_security.v1.RouteB\x04\xc8\xde\x1f\x00R\x05route\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner:E\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*6hyperlane/v1/MsgCreateRoMsgSetRoutingIsmDomainutingIsm\" \n\x1eMsgSetRoutingIsmDomainResponse\"\xdc\x01\n\x19MsgRemoveRoutingIsmDomain\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12\x16\n\x06\x64omain\x18\x02 \x01(\rR\x06\x64omain\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner:5\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*&hyperlane/v1/MsgRemoveRoutingIsmDomain\"#\n!MsgRemoveRoutingIsmDomainResponse\"\xa8\x02\n\x18MsgUpdateRoutingIsmOwner\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x35\n\tnew_owner\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08newOwner\x12-\n\x12renounce_ownership\x18\x04 \x01(\x08R\x11renounceOwnership:4\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*%hyperlane/v1/MsgUpdateRoutingIsmOwner\"\"\n MsgUpdateRoutingIsmOwnerResponse2\x97\n\n\x03Msg\x12\xb0\x01\n\x1a\x43reateMessageIdMultisigIsm\x12\x44.hyperlane.core.interchain_security.v1.MsgCreateMessageIdMultisigIsm\x1aL.hyperlane.core.interchain_security.v1.MsgCreateMessageIdMultisigIsmResponse\x12\xb3\x01\n\x1b\x43reateMerkleRootMultisigIsm\x12\x45.hyperlane.core.interchain_security.v1.MsgCreateMerkleRootMultisigIsm\x1aM.hyperlane.core.interchain_security.v1.MsgCreateMerkleRootMultisigIsmResponse\x12\x89\x01\n\rCreateNoopIsm\x12\x37.hyperlane.core.interchain_security.v1.MsgCreateNoopIsm\x1a?.hyperlane.core.interchain_security.v1.MsgCreateNoopIsmResponse\x12\x92\x01\n\x10\x43reateRoutingIsm\x12:.hyperlane.core.interchain_security.v1.MsgCreateRoutingIsm\x1a\x42.hyperlane.core.interchain_security.v1.MsgCreateRoutingIsmResponse\x12\x9b\x01\n\x13SetRoutingIsmDomain\x12=.hyperlane.core.interchain_security.v1.MsgSetRoutingIsmDomain\x1a\x45.hyperlane.core.interchain_security.v1.MsgSetRoutingIsmDomainResponse\x12\xa4\x01\n\x16RemoveRoutingIsmDomain\x12@.hyperlane.core.interchain_security.v1.MsgRemoveRoutingIsmDomain\x1aH.hyperlane.core.interchain_security.v1.MsgRemoveRoutingIsmDomainResponse\x12\xa1\x01\n\x15UpdateRoutingIsmOwner\x12?.hyperlane.core.interchain_security.v1.MsgUpdateRoutingIsmOwner\x1aG.hyperlane.core.interchain_security.v1.MsgUpdateRoutingIsmOwnerResponse\x12\x95\x01\n\x11\x41nnounceValidator\x12;.hyperlane.core.interchain_security.v1.MsgAnnounceValidator\x1a\x43.hyperlane.core.interchain_security.v1.MsgAnnounceValidatorResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xb8\x02\n)com.hyperlane.core.interchain_security.v1B\x07TxProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\007TxProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_MSGCREATEMESSAGEIDMULTISIGISM']._loaded_options = None
  _globals['_MSGCREATEMESSAGEIDMULTISIGISM']._serialized_options = b'\202\347\260*\007creator\212\347\260**hyperlane/v1/MsgCreateMessageIdMultisigIsm'
  _globals['_MSGCREATEMESSAGEIDMULTISIGISMRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEMESSAGEIDMULTISIGISMRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMERKLEROOTMULTISIGISM']._loaded_options = None
  _globals['_MSGCREATEMERKLEROOTMULTISIGISM']._serialized_options = b'\202\347\260*\007creator\212\347\260*+hyperlane/v1/MsgCreateMerkleRootMultisigIsm'
  _globals['_MSGCREATEMERKLEROOTMULTISIGISMRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEMERKLEROOTMULTISIGISMRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATENOOPISM']._loaded_options = None
  _globals['_MSGCREATENOOPISM']._serialized_options = b'\202\347\260*\007creator\212\347\260*\035hyperlane/v1/MsgCreateNoopIsm'
  _globals['_MSGCREATENOOPISMRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATENOOPISMRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGANNOUNCEVALIDATOR'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MSGANNOUNCEVALIDATOR'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGANNOUNCEVALIDATOR']._loaded_options = None
  _globals['_MSGANNOUNCEVALIDATOR']._serialized_options = b'\202\347\260*\007creator\212\347\260*!hyperlane/v1/MsgAnnounceValidator'
  _globals['_MSGCREATEROUTINGISM'].fields_by_name['routes']._loaded_options = None
  _globals['_MSGCREATEROUTINGISM'].fields_by_name['routes']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEROUTINGISM']._loaded_options = None
  _globals['_MSGCREATEROUTINGISM']._serialized_options = b'\202\347\260*\007creator\212\347\260* hyperlane/v1/MsgCreateRoutingIsm'
  _globals['_MSGCREATEROUTINGISMRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEROUTINGISMRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETROUTINGISMDOMAIN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_MSGSETROUTINGISMDOMAIN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETROUTINGISMDOMAIN'].fields_by_name['route']._loaded_options = None
  _globals['_MSGSETROUTINGISMDOMAIN'].fields_by_name['route']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETROUTINGISMDOMAIN']._loaded_options = None
  _globals['_MSGSETROUTINGISMDOMAIN']._serialized_options = b'\202\347\260*\005owner\212\347\260*6hyperlane/v1/MsgCreateRoMsgSetRoutingIsmDomainutingIsm'
  _globals['_MSGREMOVEROUTINGISMDOMAIN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_MSGREMOVEROUTINGISMDOMAIN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGREMOVEROUTINGISMDOMAIN']._loaded_options = None
  _globals['_MSGREMOVEROUTINGISMDOMAIN']._serialized_options = b'\202\347\260*\005owner\212\347\260*&hyperlane/v1/MsgRemoveRoutingIsmDomain'
  _globals['_MSGUPDATEROUTINGISMOWNER'].fields_by_name['ism_id']._loaded_options = None
  _globals['_MSGUPDATEROUTINGISMOWNER'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGUPDATEROUTINGISMOWNER'].fields_by_name['new_owner']._loaded_options = None
  _globals['_MSGUPDATEROUTINGISMOWNER'].fields_by_name['new_owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEROUTINGISMOWNER']._loaded_options = None
  _globals['_MSGUPDATEROUTINGISMOWNER']._serialized_options = b'\202\347\260*\005owner\212\347\260*%hyperlane/v1/MsgUpdateRoutingIsmOwner'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEMESSAGEIDMULTISIGISM']._serialized_start=234
  _globals['_MSGCREATEMESSAGEIDMULTISIGISM']._serialized_end=414
  _globals['_MSGCREATEMESSAGEIDMULTISIGISMRESPONSE']._serialized_start=416
  _globals['_MSGCREATEMESSAGEIDMULTISIGISMRESPONSE']._serialized_end=540
  _globals['_MSGCREATEMERKLEROOTMULTISIGISM']._serialized_start=543
  _globals['_MSGCREATEMERKLEROOTMULTISIGISM']._serialized_end=725
  _globals['_MSGCREATEMERKLEROOTMULTISIGISMRESPONSE']._serialized_start=727
  _globals['_MSGCREATEMERKLEROOTMULTISIGISMRESPONSE']._serialized_end=852
  _globals['_MSGCREATENOOPISM']._serialized_start=854
  _globals['_MSGCREATENOOPISM']._serialized_end=946
  _globals['_MSGCREATENOOPISMRESPONSE']._serialized_start=948
  _globals['_MSGCREATENOOPISMRESPONSE']._serialized_end=1059
  _globals['_MSGANNOUNCEVALIDATOR']._serialized_start=1062
  _globals['_MSGANNOUNCEVALIDATOR']._serialized_end=1365
  _globals['_MSGANNOUNCEVALIDATORRESPONSE']._serialized_start=1367
  _globals['_MSGANNOUNCEVALIDATORRESPONSE']._serialized_end=1397
  _globals['_MSGCREATEROUTINGISM']._serialized_start=1400
  _globals['_MSGCREATEROUTINGISM']._serialized_end=1574
  _globals['_MSGCREATEROUTINGISMRESPONSE']._serialized_start=1576
  _globals['_MSGCREATEROUTINGISMRESPONSE']._serialized_end=1690
  _globals['_MSGSETROUTINGISMDOMAIN']._serialized_start=1693
  _globals['_MSGSETROUTINGISMDOMAIN']._serialized_end=1976
  _globals['_MSGSETROUTINGISMDOMAINRESPONSE']._serialized_start=1978
  _globals['_MSGSETROUTINGISMDOMAINRESPONSE']._serialized_end=2010
  _globals['_MSGREMOVEROUTINGISMDOMAIN']._serialized_start=2013
  _globals['_MSGREMOVEROUTINGISMDOMAIN']._serialized_end=2233
  _globals['_MSGREMOVEROUTINGISMDOMAINRESPONSE']._serialized_start=2235
  _globals['_MSGREMOVEROUTINGISMDOMAINRESPONSE']._serialized_end=2270
  _globals['_MSGUPDATEROUTINGISMOWNER']._serialized_start=2273
  _globals['_MSGUPDATEROUTINGISMOWNER']._serialized_end=2569
  _globals['_MSGUPDATEROUTINGISMOWNERRESPONSE']._serialized_start=2571
  _globals['_MSGUPDATEROUTINGISMOWNERRESPONSE']._serialized_end=2605
  _globals['_MSG']._serialized_start=2608
  _globals['_MSG']._serialized_end=3911
# @@protoc_insertion_point(module_scope)
