# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1hyperlane/core/interchain_security/v1/query.proto\x12%hyperlane.core.interchain_security.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"Z\n\x10QueryIsmsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xdd\x01\n\x11QueryIsmsResponse\x12\x7f\n\x04isms\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyBU\xca\xb4-Qhyperlane.core.v1.01_interchain_security_module.HyperlaneInterchainSecurityModuleR\x04isms\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"!\n\x0fQueryIsmRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"E\n\x10QueryIsmResponse\x12\x31\n\x03ism\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x03ism\"s\n%QueryAnnouncedStorageLocationsRequest\x12\x1d\n\nmailbox_id\x18\x01 \x01(\tR\tmailboxId\x12+\n\x11validator_address\x18\x02 \x01(\tR\x10validatorAddress\"U\n&QueryAnnouncedStorageLocationsResponse\x12+\n\x11storage_locations\x18\x01 \x03(\tR\x10storageLocations\"x\n*QueryLatestAnnouncedStorageLocationRequest\x12\x1d\n\nmailbox_id\x18\x01 \x01(\tR\tmailboxId\x12+\n\x11validator_address\x18\x02 \x01(\tR\x10validatorAddress\"X\n+QueryLatestAnnouncedStorageLocationResponse\x12)\n\x10storage_location\x18\x01 \x01(\tR\x0fstorageLocation2\x81\x07\n\x05Query\x12\x95\x01\n\x04Isms\x12\x37.hyperlane.core.interchain_security.v1.QueryIsmsRequest\x1a\x38.hyperlane.core.interchain_security.v1.QueryIsmsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/hyperlane/v1/isms\x12\x97\x01\n\x03Ism\x12\x36.hyperlane.core.interchain_security.v1.QueryIsmRequest\x1a\x37.hyperlane.core.interchain_security.v1.QueryIsmResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/hyperlane/v1/isms/{id}\x12\x96\x02\n\x19\x41nnouncedStorageLocations\x12L.hyperlane.core.interchain_security.v1.QueryAnnouncedStorageLocationsRequest\x1aM.hyperlane.core.interchain_security.v1.QueryAnnouncedStorageLocationsResponse\"\\\x82\xd3\xe4\x93\x02V\x12T/hyperlane/v1/mailboxes/{mailbox_id}/announced_storage_locations/{validator_address}\x12\xac\x02\n\x1eLatestAnnouncedStorageLocation\x12Q.hyperlane.core.interchain_security.v1.QueryLatestAnnouncedStorageLocationRequest\x1aR.hyperlane.core.interchain_security.v1.QueryLatestAnnouncedStorageLocationResponse\"c\x82\xd3\xe4\x93\x02]\x12[/hyperlane/v1/mailboxes/{mailbox_id}/announced_storage_locations/{validator_address}/latestB\xbb\x02\n)com.hyperlane.core.interchain_security.v1B\nQueryProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\nQueryProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_QUERYISMSRESPONSE'].fields_by_name['isms']._loaded_options = None
  _globals['_QUERYISMSRESPONSE'].fields_by_name['isms']._serialized_options = b'\312\264-Qhyperlane.core.v1.01_interchain_security_module.HyperlaneInterchainSecurityModule'
  _globals['_QUERYISMRESPONSE'].fields_by_name['ism']._loaded_options = None
  _globals['_QUERYISMRESPONSE'].fields_by_name['ism']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Isms']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Isms']._serialized_options = b'\202\323\344\223\002\024\022\022/hyperlane/v1/isms'
  _globals['_QUERY'].methods_by_name['Ism']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Ism']._serialized_options = b'\202\323\344\223\002\031\022\027/hyperlane/v1/isms/{id}'
  _globals['_QUERY'].methods_by_name['AnnouncedStorageLocations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AnnouncedStorageLocations']._serialized_options = b'\202\323\344\223\002V\022T/hyperlane/v1/mailboxes/{mailbox_id}/announced_storage_locations/{validator_address}'
  _globals['_QUERY'].methods_by_name['LatestAnnouncedStorageLocation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LatestAnnouncedStorageLocation']._serialized_options = b'\202\323\344\223\002]\022[/hyperlane/v1/mailboxes/{mailbox_id}/announced_storage_locations/{validator_address}/latest'
  _globals['_QUERYISMSREQUEST']._serialized_start=261
  _globals['_QUERYISMSREQUEST']._serialized_end=351
  _globals['_QUERYISMSRESPONSE']._serialized_start=354
  _globals['_QUERYISMSRESPONSE']._serialized_end=575
  _globals['_QUERYISMREQUEST']._serialized_start=577
  _globals['_QUERYISMREQUEST']._serialized_end=610
  _globals['_QUERYISMRESPONSE']._serialized_start=612
  _globals['_QUERYISMRESPONSE']._serialized_end=681
  _globals['_QUERYANNOUNCEDSTORAGELOCATIONSREQUEST']._serialized_start=683
  _globals['_QUERYANNOUNCEDSTORAGELOCATIONSREQUEST']._serialized_end=798
  _globals['_QUERYANNOUNCEDSTORAGELOCATIONSRESPONSE']._serialized_start=800
  _globals['_QUERYANNOUNCEDSTORAGELOCATIONSRESPONSE']._serialized_end=885
  _globals['_QUERYLATESTANNOUNCEDSTORAGELOCATIONREQUEST']._serialized_start=887
  _globals['_QUERYLATESTANNOUNCEDSTORAGELOCATIONREQUEST']._serialized_end=1007
  _globals['_QUERYLATESTANNOUNCEDSTORAGELOCATIONRESPONSE']._serialized_start=1009
  _globals['_QUERYLATESTANNOUNCEDSTORAGELOCATIONRESPONSE']._serialized_end=1097
  _globals['_QUERY']._serialized_start=1100
  _globals['_QUERY']._serialized_end=1997
# @@protoc_insertion_point(module_scope)
