# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2hyperlane/core/interchain_security/v1/events.proto\x12%hyperlane.core.interchain_security.v1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xa0\x01\n\x12\x45ventCreateNoopIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\"\xec\x01\n EventCreateMerkleRootMultisigIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1e\n\nvalidators\x18\x03 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x04 \x01(\rR\tthreshold\"\xeb\x01\n\x1f\x45ventCreateMessageIdMultisigIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1e\n\nvalidators\x18\x03 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x04 \x01(\rR\tthreshold\"\xfd\x01\n\x1c\x45ventAnnounceStorageLocation\x12\x62\n\nmailbox_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x30\n\x06sender\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x1c\n\tvalidator\x18\x03 \x01(\tR\tvalidator\x12)\n\x10storage_location\x18\x04 \x01(\tR\x0fstorageLocation\"\xb0\x02\n\x18\x45ventSetRoutingIsmDomain\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x65\n\x0croute_ism_id\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\nrouteIsmId\x12!\n\x0croute_domain\x18\x04 \x01(\rR\x0brouteDomain\"\xcc\x01\n\x1b\x45ventRemoveRoutingIsmDomain\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12!\n\x0croute_domain\x18\x03 \x01(\rR\x0brouteDomain\"\xec\x01\n\x12\x45ventSetRoutingIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1b\n\tnew_owner\x18\x03 \x01(\tR\x08newOwner\x12-\n\x12renounce_ownership\x18\x04 \x01(\x08R\x11renounceOwnership\"\xa3\x01\n\x15\x45ventCreateRoutingIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05ownerB\xbc\x02\n)com.hyperlane.core.interchain_security.v1B\x0b\x45ventsProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\013EventsProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_EVENTCREATENOOPISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTCREATENOOPISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATENOOPISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTCREATENOOPISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTANNOUNCESTORAGELOCATION'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_EVENTANNOUNCESTORAGELOCATION'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTANNOUNCESTORAGELOCATION'].fields_by_name['sender']._loaded_options = None
  _globals['_EVENTANNOUNCESTORAGELOCATION'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['route_ism_id']._loaded_options = None
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['route_ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTREMOVEROUTINGISMDOMAIN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTREMOVEROUTINGISMDOMAIN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTREMOVEROUTINGISMDOMAIN'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTREMOVEROUTINGISMDOMAIN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTSETROUTINGISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTSETROUTINGISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETROUTINGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTSETROUTINGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATEROUTINGISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTCREATEROUTINGISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEROUTINGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTCREATEROUTINGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATENOOPISM']._serialized_start=143
  _globals['_EVENTCREATENOOPISM']._serialized_end=303
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM']._serialized_start=306
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM']._serialized_end=542
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM']._serialized_start=545
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM']._serialized_end=780
  _globals['_EVENTANNOUNCESTORAGELOCATION']._serialized_start=783
  _globals['_EVENTANNOUNCESTORAGELOCATION']._serialized_end=1036
  _globals['_EVENTSETROUTINGISMDOMAIN']._serialized_start=1039
  _globals['_EVENTSETROUTINGISMDOMAIN']._serialized_end=1343
  _globals['_EVENTREMOVEROUTINGISMDOMAIN']._serialized_start=1346
  _globals['_EVENTREMOVEROUTINGISMDOMAIN']._serialized_end=1550
  _globals['_EVENTSETROUTINGISM']._serialized_start=1553
  _globals['_EVENTSETROUTINGISM']._serialized_end=1789
  _globals['_EVENTCREATEROUTINGISM']._serialized_start=1792
  _globals['_EVENTCREATEROUTINGISM']._serialized_end=1955
# @@protoc_insertion_point(module_scope)
