# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from hyperlane.core.interchain_security.v1 import tx_pb2 as hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the module Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateMessageIdMultisigIsm = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/CreateMessageIdMultisigIsm',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsm.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsmResponse.FromString,
                _registered_method=True)
        self.CreateMerkleRootMultisigIsm = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/CreateMerkleRootMultisigIsm',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsm.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsmResponse.FromString,
                _registered_method=True)
        self.CreateNoopIsm = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/CreateNoopIsm',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsm.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsmResponse.FromString,
                _registered_method=True)
        self.CreateRoutingIsm = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/CreateRoutingIsm',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsm.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsmResponse.FromString,
                _registered_method=True)
        self.SetRoutingIsmDomain = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/SetRoutingIsmDomain',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomain.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomainResponse.FromString,
                _registered_method=True)
        self.RemoveRoutingIsmDomain = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/RemoveRoutingIsmDomain',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomain.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomainResponse.FromString,
                _registered_method=True)
        self.UpdateRoutingIsmOwner = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/UpdateRoutingIsmOwner',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwner.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwnerResponse.FromString,
                _registered_method=True)
        self.AnnounceValidator = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/AnnounceValidator',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidator.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidatorResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the module Msg service.
    """

    def CreateMessageIdMultisigIsm(self, request, context):
        """CreateMessageIdMultisigIsm ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMerkleRootMultisigIsm(self, request, context):
        """CreateMerkleRootMultisigIsm ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNoopIsm(self, request, context):
        """CreateNoopIsm ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRoutingIsm(self, request, context):
        """CreateRoutingIsm ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRoutingIsmDomain(self, request, context):
        """SetRoutingIsmDomain ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveRoutingIsmDomain(self, request, context):
        """RemoveRoutingIsmDomain ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRoutingIsmOwner(self, request, context):
        """UpdateRoutingIsmOwner ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AnnounceValidator(self, request, context):
        """AnnounceValidator ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateMessageIdMultisigIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMessageIdMultisigIsm,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsm.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsmResponse.SerializeToString,
            ),
            'CreateMerkleRootMultisigIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMerkleRootMultisigIsm,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsm.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsmResponse.SerializeToString,
            ),
            'CreateNoopIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNoopIsm,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsm.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsmResponse.SerializeToString,
            ),
            'CreateRoutingIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRoutingIsm,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsm.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsmResponse.SerializeToString,
            ),
            'SetRoutingIsmDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRoutingIsmDomain,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomain.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomainResponse.SerializeToString,
            ),
            'RemoveRoutingIsmDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveRoutingIsmDomain,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomain.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomainResponse.SerializeToString,
            ),
            'UpdateRoutingIsmOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRoutingIsmOwner,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwner.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwnerResponse.SerializeToString,
            ),
            'AnnounceValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.AnnounceValidator,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidator.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidatorResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperlane.core.interchain_security.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperlane.core.interchain_security.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the module Msg service.
    """

    @staticmethod
    def CreateMessageIdMultisigIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/CreateMessageIdMultisigIsm',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsm.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateMerkleRootMultisigIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/CreateMerkleRootMultisigIsm',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsm.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNoopIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/CreateNoopIsm',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsm.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateRoutingIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/CreateRoutingIsm',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsm.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetRoutingIsmDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/SetRoutingIsmDomain',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomain.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveRoutingIsmDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/RemoveRoutingIsmDomain',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomain.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateRoutingIsmOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/UpdateRoutingIsmOwner',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwner.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwnerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AnnounceValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/AnnounceValidator',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidator.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
