# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_megavault_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exchange/injective_megavault_rpc.proto\x12\x17injective_megavault_rpc\"6\n\x0fGetVaultRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\"H\n\x10GetVaultResponse\x12\x34\n\x05vault\x18\x01 \x01(\x0b\x32\x1e.injective_megavault_rpc.VaultR\x05vault\"\xe4\x04\n\x05Vault\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12#\n\rcontract_name\x18\x02 \x01(\tR\x0c\x63ontractName\x12)\n\x10\x63ontract_version\x18\x03 \x01(\tR\x0f\x63ontractVersion\x12\x14\n\x05\x61\x64min\x18\x04 \x01(\tR\x05\x61\x64min\x12\x19\n\x08lp_denom\x18\x05 \x01(\tR\x07lpDenom\x12\x1f\n\x0bquote_denom\x18\x06 \x01(\tR\nquoteDenom\x12?\n\toperators\x18\x07 \x03(\x0b\x32!.injective_megavault_rpc.OperatorR\toperators\x12\x43\n\nincentives\x18\x08 \x01(\x0b\x32#.injective_megavault_rpc.IncentivesR\nincentives\x12\x41\n\ntarget_apr\x18\t \x01(\x0b\x32\".injective_megavault_rpc.TargetAprR\ttargetApr\x12\x39\n\x05stats\x18\n \x01(\x0b\x32#.injective_megavault_rpc.VaultStatsR\x05stats\x12%\n\x0e\x63reated_height\x18\x0b \x01(\x12R\rcreatedHeight\x12\x1d\n\ncreated_at\x18\x0c \x01(\x12R\tcreatedAt\x12%\n\x0eupdated_height\x18\r \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x0e \x01(\x12R\tupdatedAt\"\x82\x02\n\x08Operator\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12!\n\x0ctotal_amount\x18\x02 \x01(\tR\x0btotalAmount\x12.\n\x13total_liquid_amount\x18\x03 \x01(\tR\x11totalLiquidAmount\x12%\n\x0eupdated_height\x18\x04 \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x05 \x01(\x12R\tupdatedAt\x12\x1e\n\npercentage\x18\x06 \x01(\tR\npercentage\x12#\n\rsubaccount_id\x18\x07 \x01(\tR\x0csubaccountId\"\x84\x01\n\nIncentives\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12%\n\x0eupdated_height\x18\x03 \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x04 \x01(\x12R\tupdatedAt\"\xb5\x01\n\tTargetApr\x12\x10\n\x03\x61pr\x18\x01 \x01(\tR\x03\x61pr\x12\'\n\x0fupper_threshold\x18\x02 \x01(\tR\x0eupperThreshold\x12\'\n\x0flower_threshold\x18\x03 \x01(\tR\x0elowerThreshold\x12%\n\x0eupdated_height\x18\x04 \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x05 \x01(\x12R\tupdatedAt\"\xbd\x04\n\nVaultStats\x12\x36\n\x17total_subscribed_amount\x18\x01 \x01(\tR\x15totalSubscribedAmount\x12\x32\n\x15total_redeemed_amount\x18\x02 \x01(\tR\x13totalRedeemedAmount\x12%\n\x0e\x63urrent_amount\x18\x03 \x01(\tR\rcurrentAmount\x12I\n!current_amount_without_incentives\x18\x04 \x01(\tR\x1e\x63urrentAmountWithoutIncentives\x12*\n\x11\x63urrent_lp_amount\x18\x05 \x01(\tR\x0f\x63urrentLpAmount\x12(\n\x10\x63urrent_lp_price\x18\x06 \x01(\tR\x0e\x63urrentLpPrice\x12\x33\n\x03pnl\x18\x07 \x01(\x0b\x32!.injective_megavault_rpc.PnlStatsR\x03pnl\x12H\n\nvolatility\x18\x08 \x01(\x0b\x32(.injective_megavault_rpc.VolatilityStatsR\nvolatility\x12\x33\n\x03\x61pr\x18\t \x01(\x0b\x32!.injective_megavault_rpc.AprStatsR\x03\x61pr\x12G\n\x0cmax_drawdown\x18\n \x01(\x0b\x32$.injective_megavault_rpc.MaxDrawdownR\x0bmaxDrawdown\"\x8b\x01\n\x08PnlStats\x12\x46\n\nunrealized\x18\x01 \x01(\x0b\x32&.injective_megavault_rpc.UnrealizedPnlR\nunrealized\x12\x37\n\x08\x61ll_time\x18\x02 \x01(\x0b\x32\x1c.injective_megavault_rpc.PnlR\x07\x61llTime\"E\n\rUnrealizedPnl\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x1e\n\npercentage\x18\x02 \x01(\tR\npercentage\"\xce\x01\n\x03Pnl\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x1e\n\npercentage\x18\x02 \x01(\tR\npercentage\x12\x36\n\x17total_amount_subscribed\x18\x03 \x01(\tR\x15totalAmountSubscribed\x12\x32\n\x15total_amount_redeemed\x18\x04 \x01(\tR\x13totalAmountRedeemed\x12%\n\x0e\x63urrent_amount\x18\x05 \x01(\tR\rcurrentAmount\"W\n\x0fVolatilityStats\x12\x44\n\x0bthirty_days\x18\x01 \x01(\x0b\x32#.injective_megavault_rpc.VolatilityR\nthirtyDays\"\"\n\nVolatility\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\"I\n\x08\x41prStats\x12=\n\x0bthirty_days\x18\x01 \x01(\x0b\x32\x1c.injective_megavault_rpc.AprR\nthirtyDays\"q\n\x03\x41pr\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12*\n\x11original_lp_price\x18\x02 \x01(\tR\x0foriginalLpPrice\x12(\n\x10\x63urrent_lp_price\x18\x03 \x01(\tR\x0e\x63urrentLpPrice\"L\n\x0bMaxDrawdown\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\'\n\x10latest_pn_l_peak\x18\x02 \x01(\tR\rlatestPnLPeak\"X\n\x0eGetUserRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12!\n\x0cuser_address\x18\x02 \x01(\tR\x0buserAddress\"D\n\x0fGetUserResponse\x12\x31\n\x04user\x18\x01 \x01(\x0b\x32\x1d.injective_megavault_rpc.UserR\x04user\"\x91\x02\n\x04User\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\x12\x38\n\x05stats\x18\x03 \x01(\x0b\x32\".injective_megavault_rpc.UserStatsR\x05stats\x12%\n\x0e\x63reated_height\x18\x04 \x01(\x12R\rcreatedHeight\x12\x1d\n\ncreated_at\x18\x05 \x01(\x12R\tcreatedAt\x12%\n\x0eupdated_height\x18\x06 \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x07 \x01(\x12R\tupdatedAt\"\xbc\x01\n\tUserStats\x12%\n\x0e\x63urrent_amount\x18\x01 \x01(\tR\rcurrentAmount\x12*\n\x11\x63urrent_lp_amount\x18\x02 \x01(\tR\x0f\x63urrentLpAmount\x12\x33\n\x03pnl\x18\x03 \x01(\x0b\x32!.injective_megavault_rpc.PnlStatsR\x03pnl\x12\'\n\x0f\x64\x65posited_value\x18\x04 \x01(\tR\x0e\x64\x65positedValue\"\xab\x01\n\x18ListSubscriptionsRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12!\n\x0cuser_address\x18\x02 \x01(\tR\x0buserAddress\x12\x16\n\x06status\x18\x03 \x01(\tR\x06status\x12\x19\n\x08per_page\x18\x04 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x05 \x01(\tR\x05token\"|\n\x19ListSubscriptionsResponse\x12K\n\rsubscriptions\x18\x01 \x03(\x0b\x32%.injective_megavault_rpc.SubscriptionR\rsubscriptions\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\"\x84\x03\n\x0cSubscription\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x14\n\x05index\x18\x03 \x01(\x12R\x05index\x12\x1b\n\tlp_amount\x18\x04 \x01(\tR\x08lpAmount\x12\x16\n\x06\x61mount\x18\x05 \x01(\tR\x06\x61mount\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12%\n\x0e\x63reated_height\x18\x07 \x01(\x12R\rcreatedHeight\x12\x1d\n\ncreated_at\x18\x08 \x01(\x12R\tcreatedAt\x12\'\n\x0f\x65xecuted_height\x18\t \x01(\x12R\x0e\x65xecutedHeight\x12\x1f\n\x0b\x65xecuted_at\x18\n \x01(\x12R\nexecutedAt\x12\x42\n\x03log\x18\x0b \x03(\x0b\x32\x30.injective_megavault_rpc.OperationStatusLogEntryR\x03log\"\x8c\x01\n\x17OperationStatusLogEntry\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x17\n\x07tx_hash\x18\x02 \x01(\tR\x06txHash\x12!\n\x0c\x62lock_height\x18\x03 \x01(\x12R\x0b\x62lockHeight\x12\x1d\n\nblock_time\x18\x04 \x01(\x12R\tblockTime\"\xa9\x01\n\x16ListRedemptionsRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12!\n\x0cuser_address\x18\x02 \x01(\tR\x0buserAddress\x12\x16\n\x06status\x18\x03 \x01(\tR\x06status\x12\x19\n\x08per_page\x18\x04 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x05 \x01(\tR\x05token\"t\n\x17ListRedemptionsResponse\x12\x45\n\x0bredemptions\x18\x01 \x03(\x0b\x32#.injective_megavault_rpc.RedemptionR\x0bredemptions\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\"\x99\x03\n\nRedemption\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x14\n\x05index\x18\x03 \x01(\x12R\x05index\x12\x1b\n\tlp_amount\x18\x04 \x01(\tR\x08lpAmount\x12\x16\n\x06\x61mount\x18\x05 \x01(\tR\x06\x61mount\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12\x15\n\x06\x64ue_at\x18\x07 \x01(\x12R\x05\x64ueAt\x12%\n\x0e\x63reated_height\x18\x08 \x01(\x12R\rcreatedHeight\x12\x1d\n\ncreated_at\x18\t \x01(\x12R\tcreatedAt\x12\'\n\x0f\x65xecuted_height\x18\n \x01(\x12R\x0e\x65xecutedHeight\x12\x1f\n\x0b\x65xecuted_at\x18\x0b \x01(\x12R\nexecutedAt\x12\x42\n\x03log\x18\x0c \x03(\x0b\x32\x30.injective_megavault_rpc.OperationStatusLogEntryR\x03log\"u\n#GetOperatorRedemptionBucketsRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12)\n\x10operator_address\x18\x02 \x01(\tR\x0foperatorAddress\"k\n$GetOperatorRedemptionBucketsResponse\x12\x43\n\x07\x62uckets\x18\x01 \x03(\x0b\x32).injective_megavault_rpc.RedemptionBucketR\x07\x62uckets\"\xab\x01\n\x10RedemptionBucket\x12\x16\n\x06\x62ucket\x18\x01 \x01(\tR\x06\x62ucket\x12-\n\x13lp_amount_to_redeem\x18\x02 \x01(\tR\x10lpAmountToRedeem\x12#\n\rneeded_amount\x18\x03 \x01(\tR\x0cneededAmount\x12+\n\x11missing_liquidity\x18\x04 \x01(\tR\x10missingLiquidity\"v\n\x11TvlHistoryRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12\x14\n\x05since\x18\x02 \x01(\x12R\x05since\x12&\n\x0fmax_data_points\x18\x03 \x01(\x11R\rmaxDataPoints\"V\n\x12TvlHistoryResponse\x12@\n\x07history\x18\x01 \x03(\x0b\x32&.injective_megavault_rpc.HistoricalTVLR\x07history\"+\n\rHistoricalTVL\x12\x0c\n\x01t\x18\x01 \x01(\x12R\x01t\x12\x0c\n\x01v\x18\x02 \x01(\tR\x01v\"v\n\x11PnlHistoryRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12\x14\n\x05since\x18\x02 \x01(\x12R\x05since\x12&\n\x0fmax_data_points\x18\x03 \x01(\x11R\rmaxDataPoints\"V\n\x12PnlHistoryResponse\x12@\n\x07history\x18\x01 \x03(\x0b\x32&.injective_megavault_rpc.HistoricalPnLR\x07history\"+\n\rHistoricalPnL\x12\x0c\n\x01t\x18\x01 \x01(\x12R\x01t\x12\x0c\n\x01v\x18\x02 \x01(\tR\x01v2\xb4\x06\n\x15InjectiveMegavaultRPC\x12_\n\x08GetVault\x12(.injective_megavault_rpc.GetVaultRequest\x1a).injective_megavault_rpc.GetVaultResponse\x12\\\n\x07GetUser\x12\'.injective_megavault_rpc.GetUserRequest\x1a(.injective_megavault_rpc.GetUserResponse\x12z\n\x11ListSubscriptions\x12\x31.injective_megavault_rpc.ListSubscriptionsRequest\x1a\x32.injective_megavault_rpc.ListSubscriptionsResponse\x12t\n\x0fListRedemptions\x12/.injective_megavault_rpc.ListRedemptionsRequest\x1a\x30.injective_megavault_rpc.ListRedemptionsResponse\x12\x9b\x01\n\x1cGetOperatorRedemptionBuckets\x12<.injective_megavault_rpc.GetOperatorRedemptionBucketsRequest\x1a=.injective_megavault_rpc.GetOperatorRedemptionBucketsResponse\x12\x65\n\nTvlHistory\x12*.injective_megavault_rpc.TvlHistoryRequest\x1a+.injective_megavault_rpc.TvlHistoryResponse\x12\x65\n\nPnlHistory\x12*.injective_megavault_rpc.PnlHistoryRequest\x1a+.injective_megavault_rpc.PnlHistoryResponseB\xc9\x01\n\x1b\x63om.injective_megavault_rpcB\x1aInjectiveMegavaultRpcProtoP\x01Z\x1a/injective_megavault_rpcpb\xa2\x02\x03IXX\xaa\x02\x15InjectiveMegavaultRpc\xca\x02\x15InjectiveMegavaultRpc\xe2\x02!InjectiveMegavaultRpc\\GPBMetadata\xea\x02\x15InjectiveMegavaultRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_megavault_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective_megavault_rpcB\032InjectiveMegavaultRpcProtoP\001Z\032/injective_megavault_rpcpb\242\002\003IXX\252\002\025InjectiveMegavaultRpc\312\002\025InjectiveMegavaultRpc\342\002!InjectiveMegavaultRpc\\GPBMetadata\352\002\025InjectiveMegavaultRpc'
  _globals['_GETVAULTREQUEST']._serialized_start=67
  _globals['_GETVAULTREQUEST']._serialized_end=121
  _globals['_GETVAULTRESPONSE']._serialized_start=123
  _globals['_GETVAULTRESPONSE']._serialized_end=195
  _globals['_VAULT']._serialized_start=198
  _globals['_VAULT']._serialized_end=810
  _globals['_OPERATOR']._serialized_start=813
  _globals['_OPERATOR']._serialized_end=1071
  _globals['_INCENTIVES']._serialized_start=1074
  _globals['_INCENTIVES']._serialized_end=1206
  _globals['_TARGETAPR']._serialized_start=1209
  _globals['_TARGETAPR']._serialized_end=1390
  _globals['_VAULTSTATS']._serialized_start=1393
  _globals['_VAULTSTATS']._serialized_end=1966
  _globals['_PNLSTATS']._serialized_start=1969
  _globals['_PNLSTATS']._serialized_end=2108
  _globals['_UNREALIZEDPNL']._serialized_start=2110
  _globals['_UNREALIZEDPNL']._serialized_end=2179
  _globals['_PNL']._serialized_start=2182
  _globals['_PNL']._serialized_end=2388
  _globals['_VOLATILITYSTATS']._serialized_start=2390
  _globals['_VOLATILITYSTATS']._serialized_end=2477
  _globals['_VOLATILITY']._serialized_start=2479
  _globals['_VOLATILITY']._serialized_end=2513
  _globals['_APRSTATS']._serialized_start=2515
  _globals['_APRSTATS']._serialized_end=2588
  _globals['_APR']._serialized_start=2590
  _globals['_APR']._serialized_end=2703
  _globals['_MAXDRAWDOWN']._serialized_start=2705
  _globals['_MAXDRAWDOWN']._serialized_end=2781
  _globals['_GETUSERREQUEST']._serialized_start=2783
  _globals['_GETUSERREQUEST']._serialized_end=2871
  _globals['_GETUSERRESPONSE']._serialized_start=2873
  _globals['_GETUSERRESPONSE']._serialized_end=2941
  _globals['_USER']._serialized_start=2944
  _globals['_USER']._serialized_end=3217
  _globals['_USERSTATS']._serialized_start=3220
  _globals['_USERSTATS']._serialized_end=3408
  _globals['_LISTSUBSCRIPTIONSREQUEST']._serialized_start=3411
  _globals['_LISTSUBSCRIPTIONSREQUEST']._serialized_end=3582
  _globals['_LISTSUBSCRIPTIONSRESPONSE']._serialized_start=3584
  _globals['_LISTSUBSCRIPTIONSRESPONSE']._serialized_end=3708
  _globals['_SUBSCRIPTION']._serialized_start=3711
  _globals['_SUBSCRIPTION']._serialized_end=4099
  _globals['_OPERATIONSTATUSLOGENTRY']._serialized_start=4102
  _globals['_OPERATIONSTATUSLOGENTRY']._serialized_end=4242
  _globals['_LISTREDEMPTIONSREQUEST']._serialized_start=4245
  _globals['_LISTREDEMPTIONSREQUEST']._serialized_end=4414
  _globals['_LISTREDEMPTIONSRESPONSE']._serialized_start=4416
  _globals['_LISTREDEMPTIONSRESPONSE']._serialized_end=4532
  _globals['_REDEMPTION']._serialized_start=4535
  _globals['_REDEMPTION']._serialized_end=4944
  _globals['_GETOPERATORREDEMPTIONBUCKETSREQUEST']._serialized_start=4946
  _globals['_GETOPERATORREDEMPTIONBUCKETSREQUEST']._serialized_end=5063
  _globals['_GETOPERATORREDEMPTIONBUCKETSRESPONSE']._serialized_start=5065
  _globals['_GETOPERATORREDEMPTIONBUCKETSRESPONSE']._serialized_end=5172
  _globals['_REDEMPTIONBUCKET']._serialized_start=5175
  _globals['_REDEMPTIONBUCKET']._serialized_end=5346
  _globals['_TVLHISTORYREQUEST']._serialized_start=5348
  _globals['_TVLHISTORYREQUEST']._serialized_end=5466
  _globals['_TVLHISTORYRESPONSE']._serialized_start=5468
  _globals['_TVLHISTORYRESPONSE']._serialized_end=5554
  _globals['_HISTORICALTVL']._serialized_start=5556
  _globals['_HISTORICALTVL']._serialized_end=5599
  _globals['_PNLHISTORYREQUEST']._serialized_start=5601
  _globals['_PNLHISTORYREQUEST']._serialized_end=5719
  _globals['_PNLHISTORYRESPONSE']._serialized_start=5721
  _globals['_PNLHISTORYRESPONSE']._serialized_end=5807
  _globals['_HISTORICALPNL']._serialized_start=5809
  _globals['_HISTORICALPNL']._serialized_end=5852
  _globals['_INJECTIVEMEGAVAULTRPC']._serialized_start=5855
  _globals['_INJECTIVEMEGAVAULTRPC']._serialized_end=6675
# @@protoc_insertion_point(module_scope)
