# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/rate_limit.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/peggy/v1/rate_limit.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\"\x85\x03\n\tRateLimit\x12#\n\rtoken_address\x18\x01 \x01(\tR\x0ctokenAddress\x12%\n\x0etoken_decimals\x18\x02 \x01(\rR\rtokenDecimals\x12$\n\x0etoken_price_id\x18\x03 \x01(\tR\x0ctokenPriceId\x12*\n\x11rate_limit_window\x18\x04 \x01(\x04R\x0frateLimitWindow\x12I\n\x0erate_limit_usd\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0crateLimitUsd\x12M\n\x13\x61\x62solute_mint_limit\x18\x06 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x11\x61\x62soluteMintLimit\x12@\n\ttransfers\x18\x07 \x03(\x0b\x32\".injective.peggy.v1.BridgeTransferR\ttransfers\"\x89\x01\n\x0e\x42ridgeTransfer\x12\x35\n\x06\x61mount\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x06\x61mount\x12!\n\x0c\x62lock_number\x18\x02 \x01(\x04R\x0b\x62lockNumber\x12\x1d\n\nis_deposit\x18\x03 \x01(\x08R\tisDepositB\xdf\x01\n\x16\x63om.injective.peggy.v1B\x0eRateLimitProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\xa2\x02\x03IPX\xaa\x02\x12Injective.Peggy.V1\xca\x02\x12Injective\\Peggy\\V1\xe2\x02\x1eInjective\\Peggy\\V1\\GPBMetadata\xea\x02\x14Injective::Peggy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.rate_limit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.peggy.v1B\016RateLimitProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\242\002\003IPX\252\002\022Injective.Peggy.V1\312\002\022Injective\\Peggy\\V1\342\002\036Injective\\Peggy\\V1\\GPBMetadata\352\002\024Injective::Peggy::V1'
  _globals['_RATELIMIT'].fields_by_name['rate_limit_usd']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['rate_limit_usd']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_RATELIMIT'].fields_by_name['absolute_mint_limit']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['absolute_mint_limit']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_BRIDGETRANSFER'].fields_by_name['amount']._loaded_options = None
  _globals['_BRIDGETRANSFER'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_RATELIMIT']._serialized_start=82
  _globals['_RATELIMIT']._serialized_end=471
  _globals['_BRIDGETRANSFER']._serialized_start=474
  _globals['_BRIDGETRANSFER']._serialized_end=611
# @@protoc_insertion_point(module_scope)
