# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhyperlane/core/v1/types.proto\x12\x11hyperlane.core.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"\xb7\x04\n\x07Mailbox\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12!\n\x0cmessage_sent\x18\x03 \x01(\rR\x0bmessageSent\x12)\n\x10message_received\x18\x04 \x01(\rR\x0fmessageReceived\x12\x64\n\x0b\x64\x65\x66\x61ult_ism\x18\x05 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\ndefaultIsm\x12\x66\n\x0c\x64\x65\x66\x61ult_hook\x18\x06 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0b\x64\x65\x66\x61ultHook\x12h\n\rrequired_hook\x18\x07 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0crequiredHook\x12!\n\x0clocal_domain\x18\x08 \x01(\rR\x0blocalDomainB\xc3\x01\n\x15\x63om.hyperlane.core.v1B\nTypesProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\xa2\x02\x03HCX\xaa\x02\x11Hyperlane.Core.V1\xca\x02\x11Hyperlane\\Core\\V1\xe2\x02\x1dHyperlane\\Core\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.core.v1B\nTypesProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\242\002\003HCX\252\002\021Hyperlane.Core.V1\312\002\021Hyperlane\\Core\\V1\342\002\035Hyperlane\\Core\\V1\\GPBMetadata\352\002\023Hyperlane::Core::V1'
  _globals['_MAILBOX'].fields_by_name['id']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MAILBOX'].fields_by_name['owner']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MAILBOX'].fields_by_name['default_ism']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['default_ism']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MAILBOX'].fields_by_name['default_hook']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['default_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MAILBOX'].fields_by_name['required_hook']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['required_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MAILBOX']._serialized_start=102
  _globals['_MAILBOX']._serialized_end=669
# @@protoc_insertion_point(module_scope)
