# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ehyperlane/warp/v1/events.proto\x12\x11hyperlane.warp.v1\x1a\x14gogoproto/gogo.proto\"\xa0\x02\n\x19\x45ventCreateSyntheticToken\x12^\n\x08token_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12j\n\x0eorigin_mailbox\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x04 \x01(\tR\x0boriginDenom\"\xa1\x02\n\x1a\x45ventCreateCollateralToken\x12^\n\x08token_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12j\n\x0eorigin_mailbox\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x04 \x01(\tR\x0boriginDenom\"\xe8\x01\n\rEventSetToken\x12\x19\n\x08token_id\x18\x01 \x01(\tR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12Z\n\x06ism_id\x18\x03 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12\x1b\n\tnew_owner\x18\x04 \x01(\tR\x08newOwner\x12-\n\x12renounce_ownership\x18\x05 \x01(\x08R\x11renounceOwnership\"\xd1\x01\n\x17\x45ventEnrollRemoteRouter\x12\x19\n\x08token_id\x18\x01 \x01(\tR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\'\n\x0freceiver_domain\x18\x03 \x01(\rR\x0ereceiverDomain\x12+\n\x11receiver_contract\x18\x04 \x01(\tR\x10receiverContract\x12/\n\x03gas\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x03gas\"s\n\x17\x45ventUnrollRemoteRouter\x12\x19\n\x08token_id\x18\x01 \x01(\tR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\'\n\x0freceiver_domain\x18\x03 \x01(\rR\x0ereceiverDomain\"\xbb\x02\n\x17\x45ventSendRemoteTransfer\x12^\n\x08token_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12-\n\x12\x64\x65stination_domain\x18\x03 \x01(\rR\x11\x64\x65stinationDomain\x12\x61\n\trecipient\x18\x04 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\trecipient\x12\x16\n\x06\x61mount\x18\x05 \x01(\tR\x06\x61mount\"\xb4\x02\n\x1a\x45ventReceiveRemoteTransfer\x12^\n\x08token_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12[\n\x06sender\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x06sender\x12#\n\rorigin_domain\x18\x03 \x01(\rR\x0coriginDomain\x12\x1c\n\trecipient\x18\x04 \x01(\tR\trecipient\x12\x16\n\x06\x61mount\x18\x05 \x01(\tR\x06\x61mountB\xc4\x01\n\x15\x63om.hyperlane.warp.v1B\x0b\x45ventsProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\013EventsProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_EVENTCREATESYNTHETICTOKEN'].fields_by_name['token_id']._loaded_options = None
  _globals['_EVENTCREATESYNTHETICTOKEN'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_EVENTCREATESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATECOLLATERALTOKEN'].fields_by_name['token_id']._loaded_options = None
  _globals['_EVENTCREATECOLLATERALTOKEN'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATECOLLATERALTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_EVENTCREATECOLLATERALTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETTOKEN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTSETTOKEN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTENROLLREMOTEROUTER'].fields_by_name['gas']._loaded_options = None
  _globals['_EVENTENROLLREMOTEROUTER'].fields_by_name['gas']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTSENDREMOTETRANSFER'].fields_by_name['token_id']._loaded_options = None
  _globals['_EVENTSENDREMOTETRANSFER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSENDREMOTETRANSFER'].fields_by_name['recipient']._loaded_options = None
  _globals['_EVENTSENDREMOTETRANSFER'].fields_by_name['recipient']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTRECEIVEREMOTETRANSFER'].fields_by_name['token_id']._loaded_options = None
  _globals['_EVENTRECEIVEREMOTETRANSFER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTRECEIVEREMOTETRANSFER'].fields_by_name['sender']._loaded_options = None
  _globals['_EVENTRECEIVEREMOTETRANSFER'].fields_by_name['sender']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATESYNTHETICTOKEN']._serialized_start=76
  _globals['_EVENTCREATESYNTHETICTOKEN']._serialized_end=364
  _globals['_EVENTCREATECOLLATERALTOKEN']._serialized_start=367
  _globals['_EVENTCREATECOLLATERALTOKEN']._serialized_end=656
  _globals['_EVENTSETTOKEN']._serialized_start=659
  _globals['_EVENTSETTOKEN']._serialized_end=891
  _globals['_EVENTENROLLREMOTEROUTER']._serialized_start=894
  _globals['_EVENTENROLLREMOTEROUTER']._serialized_end=1103
  _globals['_EVENTUNROLLREMOTEROUTER']._serialized_start=1105
  _globals['_EVENTUNROLLREMOTEROUTER']._serialized_end=1220
  _globals['_EVENTSENDREMOTETRANSFER']._serialized_start=1223
  _globals['_EVENTSENDREMOTETRANSFER']._serialized_end=1538
  _globals['_EVENTRECEIVEREMOTETRANSFER']._serialized_start=1541
  _globals['_EVENTRECEIVEREMOTETRANSFER']._serialized_end=1849
# @@protoc_insertion_point(module_scope)
