# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_auction_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$exchange/injective_auction_rpc.proto\x12\x15injective_auction_rpc\".\n\x16\x41uctionEndpointRequest\x12\x14\n\x05round\x18\x01 \x01(\x12R\x05round\"\x83\x01\n\x17\x41uctionEndpointResponse\x12\x38\n\x07\x61uction\x18\x01 \x01(\x0b\x32\x1e.injective_auction_rpc.AuctionR\x07\x61uction\x12.\n\x04\x62ids\x18\x02 \x03(\x0b\x32\x1a.injective_auction_rpc.BidR\x04\x62ids\"\xa2\x02\n\x07\x41uction\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x33\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32\x1b.injective_auction_rpc.CoinR\x06\x62\x61sket\x12,\n\x12winning_bid_amount\x18\x03 \x01(\tR\x10winningBidAmount\x12\x14\n\x05round\x18\x04 \x01(\x04R\x05round\x12#\n\rend_timestamp\x18\x05 \x01(\x12R\x0c\x65ndTimestamp\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\x12\x42\n\x08\x63ontract\x18\x07 \x01(\x0b\x32&.injective_auction_rpc.AuctionContractR\x08\x63ontract\"Q\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1b\n\tusd_value\x18\x03 \x01(\tR\x08usdValue\"\xb4\x03\n\x0f\x41uctionContract\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x1d\n\nbid_target\x18\x02 \x01(\tR\tbidTarget\x12#\n\rcurrent_slots\x18\x03 \x01(\x04R\x0c\x63urrentSlots\x12\x1f\n\x0btotal_slots\x18\x04 \x01(\x04R\ntotalSlots\x12.\n\x13max_user_allocation\x18\x05 \x01(\tR\x11maxUserAllocation\x12\'\n\x0ftotal_committed\x18\x06 \x01(\tR\x0etotalCommitted\x12/\n\x13whitelist_addresses\x18\x07 \x03(\tR\x12whitelistAddresses\x12\'\n\x0fstart_timestamp\x18\x08 \x01(\x04R\x0estartTimestamp\x12#\n\rend_timestamp\x18\t \x01(\x04R\x0c\x65ndTimestamp\x12\x30\n\x14max_round_allocation\x18\n \x01(\tR\x12maxRoundAllocation\x12\"\n\ris_bid_placed\x18\x0b \x01(\x08R\x0bisBidPlaced\"S\n\x03\x42id\x12\x16\n\x06\x62idder\x18\x01 \x01(\tR\x06\x62idder\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\x11\n\x0f\x41uctionsRequest\"N\n\x10\x41uctionsResponse\x12:\n\x08\x61uctions\x18\x01 \x03(\x0b\x32\x1e.injective_auction_rpc.AuctionR\x08\x61uctions\"f\n\x18\x41uctionsHistoryV2Request\x12\x19\n\x08per_page\x18\x01 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\x12\x19\n\x08\x65nd_time\x18\x03 \x01(\x12R\x07\x65ndTime\"s\n\x19\x41uctionsHistoryV2Response\x12\x42\n\x08\x61uctions\x18\x01 \x03(\x0b\x32&.injective_auction_rpc.AuctionV2ResultR\x08\x61uctions\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\"\xe5\x02\n\x0f\x41uctionV2Result\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x39\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32!.injective_auction_rpc.CoinPricesR\x06\x62\x61sket\x12,\n\x12winning_bid_amount\x18\x03 \x01(\tR\x10winningBidAmount\x12\x14\n\x05round\x18\x04 \x01(\x04R\x05round\x12#\n\rend_timestamp\x18\x05 \x01(\x12R\x0c\x65ndTimestamp\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\x12\x42\n\x08\x63ontract\x18\x07 \x01(\x0b\x32&.injective_auction_rpc.AuctionContractR\x08\x63ontract\x12\x33\n\x16winning_bid_amount_usd\x18\x08 \x01(\tR\x13winningBidAmountUsd\"\xbc\x01\n\nCoinPrices\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x45\n\x06prices\x18\x03 \x03(\x0b\x32-.injective_auction_rpc.CoinPrices.PricesEntryR\x06prices\x1a\x39\n\x0bPricesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"(\n\x10\x41uctionV2Request\x12\x14\n\x05round\x18\x01 \x01(\x12R\x05round\"\xe7\x02\n\x11\x41uctionV2Response\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x39\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32!.injective_auction_rpc.CoinPricesR\x06\x62\x61sket\x12,\n\x12winning_bid_amount\x18\x03 \x01(\tR\x10winningBidAmount\x12\x14\n\x05round\x18\x04 \x01(\x04R\x05round\x12#\n\rend_timestamp\x18\x05 \x01(\x12R\x0c\x65ndTimestamp\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\x12\x42\n\x08\x63ontract\x18\x07 \x01(\x0b\x32&.injective_auction_rpc.AuctionContractR\x08\x63ontract\x12\x33\n\x16winning_bid_amount_usd\x18\x08 \x01(\tR\x13winningBidAmountUsd\"e\n\x18\x41\x63\x63ountAuctionsV2Request\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x19\n\x08per_page\x18\x02 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x03 \x01(\tR\x05token\"\x8a\x01\n\x19\x41\x63\x63ountAuctionsV2Response\x12\x43\n\x08\x61uctions\x18\x01 \x03(\x0b\x32\'.injective_auction_rpc.AccountAuctionV2R\x08\x61uctions\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\x12\x14\n\x05total\x18\x03 \x01(\x12R\x05total\"\xd0\x01\n\x10\x41\x63\x63ountAuctionV2\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x14\n\x05round\x18\x02 \x01(\x04R\x05round\x12)\n\x10\x61mount_deposited\x18\x03 \x01(\tR\x0f\x61mountDeposited\x12!\n\x0cis_claimable\x18\x04 \x01(\x08R\x0bisClaimable\x12H\n\x0e\x63laimed_assets\x18\x05 \x03(\x0b\x32!.injective_auction_rpc.CoinPricesR\rclaimedAssets\"M\n\x1b\x41uctionAccountStatusRequest\x12\x14\n\x05round\x18\x01 \x01(\x12R\x05round\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"6\n\x1c\x41uctionAccountStatusResponse\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"\x13\n\x11StreamBidsRequest\"\x7f\n\x12StreamBidsResponse\x12\x16\n\x06\x62idder\x18\x01 \x01(\tR\x06\x62idder\x12\x1d\n\nbid_amount\x18\x02 \x01(\tR\tbidAmount\x12\x14\n\x05round\x18\x03 \x01(\x04R\x05round\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"\x19\n\x17InjBurntEndpointRequest\"B\n\x18InjBurntEndpointResponse\x12&\n\x0ftotal_inj_burnt\x18\x01 \x01(\tR\rtotalInjBurnt\"\x16\n\x14\x41uctionsStatsRequest\"`\n\x15\x41uctionsStatsResponse\x12\x1f\n\x0btotal_burnt\x18\x01 \x01(\tR\ntotalBurnt\x12&\n\x0ftotal_usd_value\x18\x02 \x01(\tR\rtotalUsdValue2\xfb\x07\n\x13InjectiveAuctionRPC\x12p\n\x0f\x41uctionEndpoint\x12-.injective_auction_rpc.AuctionEndpointRequest\x1a..injective_auction_rpc.AuctionEndpointResponse\x12[\n\x08\x41uctions\x12&.injective_auction_rpc.AuctionsRequest\x1a\'.injective_auction_rpc.AuctionsResponse\x12v\n\x11\x41uctionsHistoryV2\x12/.injective_auction_rpc.AuctionsHistoryV2Request\x1a\x30.injective_auction_rpc.AuctionsHistoryV2Response\x12^\n\tAuctionV2\x12\'.injective_auction_rpc.AuctionV2Request\x1a(.injective_auction_rpc.AuctionV2Response\x12v\n\x11\x41\x63\x63ountAuctionsV2\x12/.injective_auction_rpc.AccountAuctionsV2Request\x1a\x30.injective_auction_rpc.AccountAuctionsV2Response\x12\x7f\n\x14\x41uctionAccountStatus\x12\x32.injective_auction_rpc.AuctionAccountStatusRequest\x1a\x33.injective_auction_rpc.AuctionAccountStatusResponse\x12\x63\n\nStreamBids\x12(.injective_auction_rpc.StreamBidsRequest\x1a).injective_auction_rpc.StreamBidsResponse0\x01\x12s\n\x10InjBurntEndpoint\x12..injective_auction_rpc.InjBurntEndpointRequest\x1a/.injective_auction_rpc.InjBurntEndpointResponse\x12j\n\rAuctionsStats\x12+.injective_auction_rpc.AuctionsStatsRequest\x1a,.injective_auction_rpc.AuctionsStatsResponseB\xbb\x01\n\x19\x63om.injective_auction_rpcB\x18InjectiveAuctionRpcProtoP\x01Z\x18/injective_auction_rpcpb\xa2\x02\x03IXX\xaa\x02\x13InjectiveAuctionRpc\xca\x02\x13InjectiveAuctionRpc\xe2\x02\x1fInjectiveAuctionRpc\\GPBMetadata\xea\x02\x13InjectiveAuctionRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_auction_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective_auction_rpcB\030InjectiveAuctionRpcProtoP\001Z\030/injective_auction_rpcpb\242\002\003IXX\252\002\023InjectiveAuctionRpc\312\002\023InjectiveAuctionRpc\342\002\037InjectiveAuctionRpc\\GPBMetadata\352\002\023InjectiveAuctionRpc'
  _globals['_COINPRICES_PRICESENTRY']._loaded_options = None
  _globals['_COINPRICES_PRICESENTRY']._serialized_options = b'8\001'
  _globals['_AUCTIONENDPOINTREQUEST']._serialized_start=63
  _globals['_AUCTIONENDPOINTREQUEST']._serialized_end=109
  _globals['_AUCTIONENDPOINTRESPONSE']._serialized_start=112
  _globals['_AUCTIONENDPOINTRESPONSE']._serialized_end=243
  _globals['_AUCTION']._serialized_start=246
  _globals['_AUCTION']._serialized_end=536
  _globals['_COIN']._serialized_start=538
  _globals['_COIN']._serialized_end=619
  _globals['_AUCTIONCONTRACT']._serialized_start=622
  _globals['_AUCTIONCONTRACT']._serialized_end=1058
  _globals['_BID']._serialized_start=1060
  _globals['_BID']._serialized_end=1143
  _globals['_AUCTIONSREQUEST']._serialized_start=1145
  _globals['_AUCTIONSREQUEST']._serialized_end=1162
  _globals['_AUCTIONSRESPONSE']._serialized_start=1164
  _globals['_AUCTIONSRESPONSE']._serialized_end=1242
  _globals['_AUCTIONSHISTORYV2REQUEST']._serialized_start=1244
  _globals['_AUCTIONSHISTORYV2REQUEST']._serialized_end=1346
  _globals['_AUCTIONSHISTORYV2RESPONSE']._serialized_start=1348
  _globals['_AUCTIONSHISTORYV2RESPONSE']._serialized_end=1463
  _globals['_AUCTIONV2RESULT']._serialized_start=1466
  _globals['_AUCTIONV2RESULT']._serialized_end=1823
  _globals['_COINPRICES']._serialized_start=1826
  _globals['_COINPRICES']._serialized_end=2014
  _globals['_COINPRICES_PRICESENTRY']._serialized_start=1957
  _globals['_COINPRICES_PRICESENTRY']._serialized_end=2014
  _globals['_AUCTIONV2REQUEST']._serialized_start=2016
  _globals['_AUCTIONV2REQUEST']._serialized_end=2056
  _globals['_AUCTIONV2RESPONSE']._serialized_start=2059
  _globals['_AUCTIONV2RESPONSE']._serialized_end=2418
  _globals['_ACCOUNTAUCTIONSV2REQUEST']._serialized_start=2420
  _globals['_ACCOUNTAUCTIONSV2REQUEST']._serialized_end=2521
  _globals['_ACCOUNTAUCTIONSV2RESPONSE']._serialized_start=2524
  _globals['_ACCOUNTAUCTIONSV2RESPONSE']._serialized_end=2662
  _globals['_ACCOUNTAUCTIONV2']._serialized_start=2665
  _globals['_ACCOUNTAUCTIONV2']._serialized_end=2873
  _globals['_AUCTIONACCOUNTSTATUSREQUEST']._serialized_start=2875
  _globals['_AUCTIONACCOUNTSTATUSREQUEST']._serialized_end=2952
  _globals['_AUCTIONACCOUNTSTATUSRESPONSE']._serialized_start=2954
  _globals['_AUCTIONACCOUNTSTATUSRESPONSE']._serialized_end=3008
  _globals['_STREAMBIDSREQUEST']._serialized_start=3010
  _globals['_STREAMBIDSREQUEST']._serialized_end=3029
  _globals['_STREAMBIDSRESPONSE']._serialized_start=3031
  _globals['_STREAMBIDSRESPONSE']._serialized_end=3158
  _globals['_INJBURNTENDPOINTREQUEST']._serialized_start=3160
  _globals['_INJBURNTENDPOINTREQUEST']._serialized_end=3185
  _globals['_INJBURNTENDPOINTRESPONSE']._serialized_start=3187
  _globals['_INJBURNTENDPOINTRESPONSE']._serialized_end=3253
  _globals['_AUCTIONSSTATSREQUEST']._serialized_start=3255
  _globals['_AUCTIONSSTATSREQUEST']._serialized_end=3277
  _globals['_AUCTIONSSTATSRESPONSE']._serialized_start=3279
  _globals['_AUCTIONSSTATSRESPONSE']._serialized_end=3375
  _globals['_INJECTIVEAUCTIONRPC']._serialized_start=3378
  _globals['_INJECTIVEAUCTIONRPC']._serialized_end=4397
# @@protoc_insertion_point(module_scope)
