# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hyperlane.core.v1 import types_pb2 as hyperlane_dot_core_dot_v1_dot_types__pb2
from hyperlane.core.interchain_security.v1 import genesis_pb2 as hyperlane_dot_core_dot_interchain__security_dot_v1_dot_genesis__pb2
from hyperlane.core.post_dispatch.v1 import genesis_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_genesis__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fhyperlane/core/v1/genesis.proto\x12\x11hyperlane.core.v1\x1a\x1dhyperlane/core/v1/types.proto\x1a\x33hyperlane/core/interchain_security/v1/genesis.proto\x1a-hyperlane/core/post_dispatch/v1/genesis.proto\x1a\x14gogoproto/gogo.proto\"\xd6\x03\n\x0cGenesisState\x12T\n\x0bism_genesis\x18\x01 \x01(\x0b\x32\x33.hyperlane.core.interchain_security.v1.GenesisStateR\nismGenesis\x12\x61\n\x15post_dispatch_genesis\x18\x02 \x01(\x0b\x32-.hyperlane.core.post_dispatch.v1.GenesisStateR\x13postDispatchGenesis\x12>\n\tmailboxes\x18\x03 \x03(\x0b\x32\x1a.hyperlane.core.v1.MailboxB\x04\xc8\xde\x1f\x00R\tmailboxes\x12Q\n\x08messages\x18\x04 \x03(\x0b\x32/.hyperlane.core.v1.GenesisMailboxMessageWrapperB\x04\xc8\xde\x1f\x00R\x08messages\x12!\n\x0cism_sequence\x18\x05 \x01(\x04R\x0bismSequence\x12\x34\n\x16post_dispatch_sequence\x18\x06 \x01(\x04R\x14postDispatchSequence\x12!\n\x0c\x61pp_sequence\x18\x07 \x01(\x04R\x0b\x61ppSequence\"\xa1\x01\n\x1cGenesisMailboxMessageWrapper\x12\x1d\n\nmailbox_id\x18\x01 \x01(\x04R\tmailboxId\x12\x62\n\nmessage_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageIdB\xc5\x01\n\x15\x63om.hyperlane.core.v1B\x0cGenesisProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\xa2\x02\x03HCX\xaa\x02\x11Hyperlane.Core.V1\xca\x02\x11Hyperlane\\Core\\V1\xe2\x02\x1dHyperlane\\Core\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.core.v1B\014GenesisProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\242\002\003HCX\252\002\021Hyperlane.Core.V1\312\002\021Hyperlane\\Core\\V1\342\002\035Hyperlane\\Core\\V1\\GPBMetadata\352\002\023Hyperlane::Core::V1'
  _globals['_GENESISSTATE'].fields_by_name['mailboxes']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['mailboxes']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['messages']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['messages']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISMAILBOXMESSAGEWRAPPER'].fields_by_name['message_id']._loaded_options = None
  _globals['_GENESISMAILBOXMESSAGEWRAPPER'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_GENESISSTATE']._serialized_start=208
  _globals['_GENESISSTATE']._serialized_end=678
  _globals['_GENESISMAILBOXMESSAGEWRAPPER']._serialized_start=681
  _globals['_GENESISMAILBOXMESSAGEWRAPPER']._serialized_end=842
# @@protoc_insertion_point(module_scope)
