# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhyperlane/warp/v1/types.proto\x12\x11hyperlane.warp.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"$\n\x06Params:\x1a\x8a\xe7\xb0*\x15hyperlane/warp/Params\"\x88\x04\n\x08HypToken\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12>\n\ntoken_type\x18\x03 \x01(\x0e\x32\x1f.hyperlane.warp.v1.HypTokenTypeR\ttokenType\x12j\n\x0eorigin_mailbox\x18\x04 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x05 \x01(\tR\x0boriginDenom\x12L\n\x12\x63ollateral_balance\x18\x06 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x11\x63ollateralBalance\x12Z\n\x06ism_id\x18\x07 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\"\x95\x01\n\x0cRemoteRouter\x12\'\n\x0freceiver_domain\x18\x01 \x01(\rR\x0ereceiverDomain\x12+\n\x11receiver_contract\x18\x02 \x01(\tR\x10receiverContract\x12/\n\x03gas\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x03gas*q\n\x0cHypTokenType\x12\x1e\n\x1aHYP_TOKEN_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19HYP_TOKEN_TYPE_COLLATERAL\x10\x01\x12\x1c\n\x18HYP_TOKEN_TYPE_SYNTHETIC\x10\x02\x1a\x04\x88\xa3\x1e\x00\x42\xc3\x01\n\x15\x63om.hyperlane.warp.v1B\nTypesProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\nTypesProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_HYPTOKENTYPE']._loaded_options = None
  _globals['_HYPTOKENTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\212\347\260*\025hyperlane/warp/Params'
  _globals['_HYPTOKEN'].fields_by_name['id']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_HYPTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_HYPTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_HYPTOKEN'].fields_by_name['collateral_balance']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['collateral_balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_HYPTOKEN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_HYPTOKEN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_REMOTEROUTER'].fields_by_name['gas']._loaded_options = None
  _globals['_REMOTEROUTER'].fields_by_name['gas']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_HYPTOKENTYPE']._serialized_start=833
  _globals['_HYPTOKENTYPE']._serialized_end=946
  _globals['_PARAMS']._serialized_start=120
  _globals['_PARAMS']._serialized_end=156
  _globals['_HYPTOKEN']._serialized_start=159
  _globals['_HYPTOKEN']._serialized_end=679
  _globals['_REMOTEROUTER']._serialized_start=682
  _globals['_REMOTEROUTER']._serialized_end=831
# @@protoc_insertion_point(module_scope)
