# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/iam/v1/iam_policy.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.google.api import client_pb2 as google_dot_api_dot_client__pb2
from pyinjective.proto.google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from pyinjective.proto.google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.iam.v1 import options_pb2 as google_dot_iam_dot_v1_dot_options__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/iam/v1/iam_policy.proto\x12\rgoogle.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/iam/v1/options.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a google/protobuf/field_mask.proto\"\xad\x01\n\x13SetIamPolicyRequest\x12%\n\x08resource\x18\x01 \x01(\tB\t\xe0\x41\x02\xfa\x41\x03\n\x01*R\x08resource\x12\x32\n\x06policy\x18\x02 \x01(\x0b\x32\x15.google.iam.v1.PolicyB\x03\xe0\x41\x02R\x06policy\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"w\n\x13GetIamPolicyRequest\x12%\n\x08resource\x18\x01 \x01(\tB\t\xe0\x41\x02\xfa\x41\x03\n\x01*R\x08resource\x12\x39\n\x07options\x18\x02 \x01(\x0b\x32\x1f.google.iam.v1.GetPolicyOptionsR\x07options\"i\n\x19TestIamPermissionsRequest\x12%\n\x08resource\x18\x01 \x01(\tB\t\xe0\x41\x02\xfa\x41\x03\n\x01*R\x08resource\x12%\n\x0bpermissions\x18\x02 \x03(\tB\x03\xe0\x41\x02R\x0bpermissions\">\n\x1aTestIamPermissionsResponse\x12 \n\x0bpermissions\x18\x01 \x03(\tR\x0bpermissions2\xb4\x03\n\tIAMPolicy\x12t\n\x0cSetIamPolicy\x12\".google.iam.v1.SetIamPolicyRequest\x1a\x15.google.iam.v1.Policy\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/{resource=**}:setIamPolicy:\x01*\x12t\n\x0cGetIamPolicy\x12\".google.iam.v1.GetIamPolicyRequest\x1a\x15.google.iam.v1.Policy\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/{resource=**}:getIamPolicy:\x01*\x12\x9a\x01\n\x12TestIamPermissions\x12(.google.iam.v1.TestIamPermissionsRequest\x1a).google.iam.v1.TestIamPermissionsResponse\"/\x82\xd3\xe4\x93\x02)\"$/v1/{resource=**}:testIamPermissions:\x01*\x1a\x1e\xca\x41\x1biam-meta-api.googleapis.comB\xa4\x01\n\x11\x63om.google.iam.v1B\x0eIamPolicyProtoP\x01Z)cloud.google.com/go/iam/apiv1/iampb;iampb\xa2\x02\x03GIX\xaa\x02\rGoogle.Iam.V1\xca\x02\rGoogle\\Iam\\V1\xe2\x02\x19Google\\Iam\\V1\\GPBMetadata\xea\x02\x0fGoogle::Iam::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.iam.v1.iam_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.google.iam.v1B\016IamPolicyProtoP\001Z)cloud.google.com/go/iam/apiv1/iampb;iampb\242\002\003GIX\252\002\rGoogle.Iam.V1\312\002\rGoogle\\Iam\\V1\342\002\031Google\\Iam\\V1\\GPBMetadata\352\002\017Google::Iam::V1'
  _globals['_SETIAMPOLICYREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_SETIAMPOLICYREQUEST'].fields_by_name['resource']._serialized_options = b'\340A\002\372A\003\n\001*'
  _globals['_SETIAMPOLICYREQUEST'].fields_by_name['policy']._loaded_options = None
  _globals['_SETIAMPOLICYREQUEST'].fields_by_name['policy']._serialized_options = b'\340A\002'
  _globals['_GETIAMPOLICYREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_GETIAMPOLICYREQUEST'].fields_by_name['resource']._serialized_options = b'\340A\002\372A\003\n\001*'
  _globals['_TESTIAMPERMISSIONSREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_TESTIAMPERMISSIONSREQUEST'].fields_by_name['resource']._serialized_options = b'\340A\002\372A\003\n\001*'
  _globals['_TESTIAMPERMISSIONSREQUEST'].fields_by_name['permissions']._loaded_options = None
  _globals['_TESTIAMPERMISSIONSREQUEST'].fields_by_name['permissions']._serialized_options = b'\340A\002'
  _globals['_IAMPOLICY']._loaded_options = None
  _globals['_IAMPOLICY']._serialized_options = b'\312A\033iam-meta-api.googleapis.com'
  _globals['_IAMPOLICY'].methods_by_name['SetIamPolicy']._loaded_options = None
  _globals['_IAMPOLICY'].methods_by_name['SetIamPolicy']._serialized_options = b'\202\323\344\223\002#\"\036/v1/{resource=**}:setIamPolicy:\001*'
  _globals['_IAMPOLICY'].methods_by_name['GetIamPolicy']._loaded_options = None
  _globals['_IAMPOLICY'].methods_by_name['GetIamPolicy']._serialized_options = b'\202\323\344\223\002#\"\036/v1/{resource=**}:getIamPolicy:\001*'
  _globals['_IAMPOLICY'].methods_by_name['TestIamPermissions']._loaded_options = None
  _globals['_IAMPOLICY'].methods_by_name['TestIamPermissions']._serialized_options = b'\202\323\344\223\002)\"$/v1/{resource=**}:testIamPermissions:\001*'
  _globals['_SETIAMPOLICYREQUEST']._serialized_start=256
  _globals['_SETIAMPOLICYREQUEST']._serialized_end=429
  _globals['_GETIAMPOLICYREQUEST']._serialized_start=431
  _globals['_GETIAMPOLICYREQUEST']._serialized_end=550
  _globals['_TESTIAMPERMISSIONSREQUEST']._serialized_start=552
  _globals['_TESTIAMPERMISSIONSREQUEST']._serialized_end=657
  _globals['_TESTIAMPERMISSIONSRESPONSE']._serialized_start=659
  _globals['_TESTIAMPERMISSIONSRESPONSE']._serialized_end=721
  _globals['_IAMPOLICY']._serialized_start=724
  _globals['_IAMPOLICY']._serialized_end=1160
# @@protoc_insertion_point(module_scope)
