# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/iam/v1/policy.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import expr_pb2 as google_dot_type_dot_expr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agoogle/iam/v1/policy.proto\x12\rgoogle.iam.v1\x1a\x16google/type/expr.proto\"\xab\x01\n\x06Policy\x12\x18\n\x07version\x18\x01 \x01(\x05R\x07version\x12\x32\n\x08\x62indings\x18\x04 \x03(\x0b\x32\x16.google.iam.v1.BindingR\x08\x62indings\x12?\n\raudit_configs\x18\x06 \x03(\x0b\x32\x1a.google.iam.v1.AuditConfigR\x0c\x61uditConfigs\x12\x12\n\x04\x65tag\x18\x03 \x01(\x0cR\x04\x65tag\"h\n\x07\x42inding\x12\x12\n\x04role\x18\x01 \x01(\tR\x04role\x12\x18\n\x07members\x18\x02 \x03(\tR\x07members\x12/\n\tcondition\x18\x03 \x01(\x0b\x32\x11.google.type.ExprR\tcondition\"r\n\x0b\x41uditConfig\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\x12I\n\x11\x61udit_log_configs\x18\x03 \x03(\x0b\x32\x1d.google.iam.v1.AuditLogConfigR\x0f\x61uditLogConfigs\"\xd1\x01\n\x0e\x41uditLogConfig\x12@\n\x08log_type\x18\x01 \x01(\x0e\x32%.google.iam.v1.AuditLogConfig.LogTypeR\x07logType\x12)\n\x10\x65xempted_members\x18\x02 \x03(\tR\x0f\x65xemptedMembers\"R\n\x07LogType\x12\x18\n\x14LOG_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nADMIN_READ\x10\x01\x12\x0e\n\nDATA_WRITE\x10\x02\x12\r\n\tDATA_READ\x10\x03\"\xa2\x01\n\x0bPolicyDelta\x12\x42\n\x0e\x62inding_deltas\x18\x01 \x03(\x0b\x32\x1b.google.iam.v1.BindingDeltaR\rbindingDeltas\x12O\n\x13\x61udit_config_deltas\x18\x02 \x03(\x0b\x32\x1f.google.iam.v1.AuditConfigDeltaR\x11\x61uditConfigDeltas\"\xde\x01\n\x0c\x42indingDelta\x12:\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\".google.iam.v1.BindingDelta.ActionR\x06\x61\x63tion\x12\x12\n\x04role\x18\x02 \x01(\tR\x04role\x12\x16\n\x06member\x18\x03 \x01(\tR\x06member\x12/\n\tcondition\x18\x04 \x01(\x0b\x32\x11.google.type.ExprR\tcondition\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\"\xe7\x01\n\x10\x41uditConfigDelta\x12>\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32&.google.iam.v1.AuditConfigDelta.ActionR\x06\x61\x63tion\x12\x18\n\x07service\x18\x02 \x01(\tR\x07service\x12\'\n\x0f\x65xempted_member\x18\x03 \x01(\tR\x0e\x65xemptedMember\x12\x19\n\x08log_type\x18\x04 \x01(\tR\x07logType\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x42\xa4\x01\n\x11\x63om.google.iam.v1B\x0bPolicyProtoP\x01Z)cloud.google.com/go/iam/apiv1/iampb;iampb\xf8\x01\x01\xa2\x02\x03GIX\xaa\x02\rGoogle.Iam.V1\xca\x02\rGoogle\\Iam\\V1\xe2\x02\x19Google\\Iam\\V1\\GPBMetadata\xea\x02\x0fGoogle::Iam::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.iam.v1.policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.google.iam.v1B\013PolicyProtoP\001Z)cloud.google.com/go/iam/apiv1/iampb;iampb\370\001\001\242\002\003GIX\252\002\rGoogle.Iam.V1\312\002\rGoogle\\Iam\\V1\342\002\031Google\\Iam\\V1\\GPBMetadata\352\002\017Google::Iam::V1'
  _globals['_POLICY']._serialized_start=70
  _globals['_POLICY']._serialized_end=241
  _globals['_BINDING']._serialized_start=243
  _globals['_BINDING']._serialized_end=347
  _globals['_AUDITCONFIG']._serialized_start=349
  _globals['_AUDITCONFIG']._serialized_end=463
  _globals['_AUDITLOGCONFIG']._serialized_start=466
  _globals['_AUDITLOGCONFIG']._serialized_end=675
  _globals['_AUDITLOGCONFIG_LOGTYPE']._serialized_start=593
  _globals['_AUDITLOGCONFIG_LOGTYPE']._serialized_end=675
  _globals['_POLICYDELTA']._serialized_start=678
  _globals['_POLICYDELTA']._serialized_end=840
  _globals['_BINDINGDELTA']._serialized_start=843
  _globals['_BINDINGDELTA']._serialized_end=1065
  _globals['_BINDINGDELTA_ACTION']._serialized_start=1012
  _globals['_BINDINGDELTA_ACTION']._serialized_end=1065
  _globals['_AUDITCONFIGDELTA']._serialized_start=1068
  _globals['_AUDITCONFIGDELTA']._serialized_end=1299
  _globals['_AUDITCONFIGDELTA_ACTION']._serialized_start=1012
  _globals['_AUDITCONFIGDELTA_ACTION']._serialized_end=1065
# @@protoc_insertion_point(module_scope)
