# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from hyperlane.warp.v1 import types_pb2 as hyperlane_dot_warp_dot_v1_dot_types__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhyperlane/warp/v1/query.proto\x12\x11hyperlane.warp.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1dhyperlane/warp/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"\\\n\x12QueryTokensRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xa5\x01\n\x13QueryTokensResponse\x12\x45\n\x06tokens\x18\x01 \x03(\x0b\x32\".hyperlane.warp.v1.WrappedHypTokenB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06tokens\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"#\n\x11QueryTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"N\n\x12QueryTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32\".hyperlane.warp.v1.WrappedHypTokenR\x05token\"\xb7\x02\n\x0fWrappedHypToken\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12>\n\ntoken_type\x18\x03 \x01(\x0e\x32\x1f.hyperlane.warp.v1.HypTokenTypeR\ttokenType\x12%\n\x0eorigin_mailbox\x18\x04 \x01(\tR\roriginMailbox\x12!\n\x0corigin_denom\x18\x05 \x01(\tR\x0boriginDenom\x12Z\n\x06ism_id\x18\x07 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\"+\n\x19QueryBridgedSupplyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"i\n\x1aQueryBridgedSupplyResponse\x12K\n\x0e\x62ridged_supply\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\rbridgedSupply\"s\n\x19QueryRemoteRoutersRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xad\x01\n\x1aQueryRemoteRoutersResponse\x12\x46\n\x0eremote_routers\x18\x01 \x03(\x0b\x32\x1f.hyperlane.warp.v1.RemoteRouterR\rremoteRouters\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xb8\x01\n\x1fQueryQuoteRemoteTransferRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12-\n\x12\x64\x65stination_domain\x18\x02 \x01(\tR\x11\x64\x65stinationDomain\x12$\n\x0e\x63ustom_hook_id\x18\x03 \x01(\tR\x0c\x63ustomHookId\x12\x30\n\x14\x63ustom_hook_metadata\x18\x04 \x01(\tR\x12\x63ustomHookMetadata\"\x95\x01\n QueryQuoteRemoteTransferResponse\x12q\n\x0bgas_payment\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01R\ngasPayment2\x88\x06\n\x05Query\x12u\n\x06Tokens\x12%.hyperlane.warp.v1.QueryTokensRequest\x1a&.hyperlane.warp.v1.QueryTokensResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/hyperlane/v1/tokens\x12w\n\x05Token\x12$.hyperlane.warp.v1.QueryTokenRequest\x1a%.hyperlane.warp.v1.QueryTokenResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/hyperlane/v1/tokens/{id}\x12\x9e\x01\n\rBridgedSupply\x12,.hyperlane.warp.v1.QueryBridgedSupplyRequest\x1a-.hyperlane.warp.v1.QueryBridgedSupplyResponse\"0\x82\xd3\xe4\x93\x02*\x12(/hyperlane/v1/tokens/{id}/bridged_supply\x12\x9e\x01\n\rRemoteRouters\x12,.hyperlane.warp.v1.QueryRemoteRoutersRequest\x1a-.hyperlane.warp.v1.QueryRemoteRoutersResponse\"0\x82\xd3\xe4\x93\x02*\x12(/hyperlane/v1/tokens/{id}/remote_routers\x12\xcc\x01\n\x13QuoteRemoteTransfer\x12\x32.hyperlane.warp.v1.QueryQuoteRemoteTransferRequest\x1a\x33.hyperlane.warp.v1.QueryQuoteRemoteTransferResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/hyperlane/v1/tokens/{id}/quote_remote_transfer/{destination_domain}B\xc3\x01\n\x15\x63om.hyperlane.warp.v1B\nQueryProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\nQueryProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_QUERYTOKENSRESPONSE'].fields_by_name['tokens']._loaded_options = None
  _globals['_QUERYTOKENSRESPONSE'].fields_by_name['tokens']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_WRAPPEDHYPTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_WRAPPEDHYPTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_WRAPPEDHYPTOKEN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_WRAPPEDHYPTOKEN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_QUERYBRIDGEDSUPPLYRESPONSE'].fields_by_name['bridged_supply']._loaded_options = None
  _globals['_QUERYBRIDGEDSUPPLYRESPONSE'].fields_by_name['bridged_supply']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYQUOTEREMOTETRANSFERRESPONSE'].fields_by_name['gas_payment']._loaded_options = None
  _globals['_QUERYQUOTEREMOTETRANSFERRESPONSE'].fields_by_name['gas_payment']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Tokens']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Tokens']._serialized_options = b'\202\323\344\223\002\026\022\024/hyperlane/v1/tokens'
  _globals['_QUERY'].methods_by_name['Token']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Token']._serialized_options = b'\202\323\344\223\002\033\022\031/hyperlane/v1/tokens/{id}'
  _globals['_QUERY'].methods_by_name['BridgedSupply']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BridgedSupply']._serialized_options = b'\202\323\344\223\002*\022(/hyperlane/v1/tokens/{id}/bridged_supply'
  _globals['_QUERY'].methods_by_name['RemoteRouters']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RemoteRouters']._serialized_options = b'\202\323\344\223\002*\022(/hyperlane/v1/tokens/{id}/remote_routers'
  _globals['_QUERY'].methods_by_name['QuoteRemoteTransfer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['QuoteRemoteTransfer']._serialized_options = b'\202\323\344\223\002F\022D/hyperlane/v1/tokens/{id}/quote_remote_transfer/{destination_domain}'
  _globals['_QUERYTOKENSREQUEST']._serialized_start=257
  _globals['_QUERYTOKENSREQUEST']._serialized_end=349
  _globals['_QUERYTOKENSRESPONSE']._serialized_start=352
  _globals['_QUERYTOKENSRESPONSE']._serialized_end=517
  _globals['_QUERYTOKENREQUEST']._serialized_start=519
  _globals['_QUERYTOKENREQUEST']._serialized_end=554
  _globals['_QUERYTOKENRESPONSE']._serialized_start=556
  _globals['_QUERYTOKENRESPONSE']._serialized_end=634
  _globals['_WRAPPEDHYPTOKEN']._serialized_start=637
  _globals['_WRAPPEDHYPTOKEN']._serialized_end=948
  _globals['_QUERYBRIDGEDSUPPLYREQUEST']._serialized_start=950
  _globals['_QUERYBRIDGEDSUPPLYREQUEST']._serialized_end=993
  _globals['_QUERYBRIDGEDSUPPLYRESPONSE']._serialized_start=995
  _globals['_QUERYBRIDGEDSUPPLYRESPONSE']._serialized_end=1100
  _globals['_QUERYREMOTEROUTERSREQUEST']._serialized_start=1102
  _globals['_QUERYREMOTEROUTERSREQUEST']._serialized_end=1217
  _globals['_QUERYREMOTEROUTERSRESPONSE']._serialized_start=1220
  _globals['_QUERYREMOTEROUTERSRESPONSE']._serialized_end=1393
  _globals['_QUERYQUOTEREMOTETRANSFERREQUEST']._serialized_start=1396
  _globals['_QUERYQUOTEREMOTETRANSFERREQUEST']._serialized_end=1580
  _globals['_QUERYQUOTEREMOTETRANSFERRESPONSE']._serialized_start=1583
  _globals['_QUERYQUOTEREMOTETRANSFERRESPONSE']._serialized_end=1732
  _globals['_QUERY']._serialized_start=1735
  _globals['_QUERY']._serialized_end=2511
# @@protoc_insertion_point(module_scope)
