# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from hyperlane.core.post_dispatch.v1 import types_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_types__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(hyperlane/core/post_dispatch/v1/tx.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a+hyperlane/core/post_dispatch/v1/types.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x91\x01\n\x0cMsgCreateIgp\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom:;\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*,hyperlane/v1/MsgCreateInterchainGasPaymaster\"k\n\x14MsgCreateIgpResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\x94\x02\n\x0eMsgSetIgpOwner\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12Z\n\x06igp_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x1b\n\tnew_owner\x18\x03 \x01(\tR\x08newOwner\x12-\n\x12renounce_ownership\x18\x04 \x01(\x08R\x11renounceOwnership:*\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\x1bhyperlane/v1/MsgSetIgpOwner\"\x18\n\x16MsgSetIgpOwnerResponse\"\xcd\x02\n\x1aMsgSetDestinationGasConfig\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12Z\n\x06igp_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12k\n\x16\x64\x65stination_gas_config\x18\x03 \x01(\x0b\x32\x35.hyperlane.core.post_dispatch.v1.DestinationGasConfigR\x14\x64\x65stinationGasConfig:6\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\'hyperlane/v1/MsgSetDestinationGasConfig\"$\n\"MsgSetDestinationGasConfigResponse\"\xd4\x03\n\x0cMsgPayForGas\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12Z\n\x06igp_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x62\n\nmessage_id\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageId\x12-\n\x12\x64\x65stination_domain\x18\x04 \x01(\rR\x11\x64\x65stinationDomain\x12:\n\tgas_limit\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasLimit\x12<\n\x06\x61mount\x18\x06 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount:)\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19hyperlane/v1/MsgPayForGas\"\x16\n\x14MsgPayForGasResponse\"\xbf\x01\n\x08MsgClaim\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12Z\n\x06igp_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId:%\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x15hyperlane/v1/MsgClaim\"\x12\n\x10MsgClaimResponse\"\xe2\x01\n\x17MsgCreateMerkleTreeHook\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x62\n\nmailbox_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId:3\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*$hyperlane/v1/MsgCreateMerkleTreeHook\"v\n\x1fMsgCreateMerkleTreeHookResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"x\n\x11MsgCreateNoopHook\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner:3\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*$hyperlane/v1/MsgCreateMerkleTreeHook\"p\n\x19MsgCreateNoopHookResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id2\x88\x07\n\x03Msg\x12q\n\tCreateIgp\x12-.hyperlane.core.post_dispatch.v1.MsgCreateIgp\x1a\x35.hyperlane.core.post_dispatch.v1.MsgCreateIgpResponse\x12w\n\x0bSetIgpOwner\x12/.hyperlane.core.post_dispatch.v1.MsgSetIgpOwner\x1a\x37.hyperlane.core.post_dispatch.v1.MsgSetIgpOwnerResponse\x12\x9b\x01\n\x17SetDestinationGasConfig\x12;.hyperlane.core.post_dispatch.v1.MsgSetDestinationGasConfig\x1a\x43.hyperlane.core.post_dispatch.v1.MsgSetDestinationGasConfigResponse\x12q\n\tPayForGas\x12-.hyperlane.core.post_dispatch.v1.MsgPayForGas\x1a\x35.hyperlane.core.post_dispatch.v1.MsgPayForGasResponse\x12\x65\n\x05\x43laim\x12).hyperlane.core.post_dispatch.v1.MsgClaim\x1a\x31.hyperlane.core.post_dispatch.v1.MsgClaimResponse\x12\x92\x01\n\x14\x43reateMerkleTreeHook\x12\x38.hyperlane.core.post_dispatch.v1.MsgCreateMerkleTreeHook\x1a@.hyperlane.core.post_dispatch.v1.MsgCreateMerkleTreeHookResponse\x12\x80\x01\n\x0e\x43reateNoopHook\x12\x32.hyperlane.core.post_dispatch.v1.MsgCreateNoopHook\x1a:.hyperlane.core.post_dispatch.v1.MsgCreateNoopHookResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x94\x02\n#com.hyperlane.core.post_dispatch.v1B\x07TxProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\007TxProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_MSGCREATEIGP'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATEIGP'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEIGP']._loaded_options = None
  _globals['_MSGCREATEIGP']._serialized_options = b'\202\347\260*\005owner\212\347\260*,hyperlane/v1/MsgCreateInterchainGasPaymaster'
  _globals['_MSGCREATEIGPRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEIGPRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETIGPOWNER'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGSETIGPOWNER'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETIGPOWNER'].fields_by_name['igp_id']._loaded_options = None
  _globals['_MSGSETIGPOWNER'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETIGPOWNER']._loaded_options = None
  _globals['_MSGSETIGPOWNER']._serialized_options = b'\202\347\260*\005owner\212\347\260*\033hyperlane/v1/MsgSetIgpOwner'
  _globals['_MSGSETDESTINATIONGASCONFIG'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGSETDESTINATIONGASCONFIG'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETDESTINATIONGASCONFIG'].fields_by_name['igp_id']._loaded_options = None
  _globals['_MSGSETDESTINATIONGASCONFIG'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETDESTINATIONGASCONFIG']._loaded_options = None
  _globals['_MSGSETDESTINATIONGASCONFIG']._serialized_options = b'\202\347\260*\005owner\212\347\260*\'hyperlane/v1/MsgSetDestinationGasConfig'
  _globals['_MSGPAYFORGAS'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGPAYFORGAS'].fields_by_name['igp_id']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGPAYFORGAS'].fields_by_name['message_id']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGPAYFORGAS'].fields_by_name['gas_limit']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['gas_limit']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MSGPAYFORGAS'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGPAYFORGAS'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGPAYFORGAS']._loaded_options = None
  _globals['_MSGPAYFORGAS']._serialized_options = b'\202\347\260*\006sender\212\347\260*\031hyperlane/v1/MsgPayForGas'
  _globals['_MSGCLAIM'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCLAIM'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCLAIM'].fields_by_name['igp_id']._loaded_options = None
  _globals['_MSGCLAIM'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCLAIM']._loaded_options = None
  _globals['_MSGCLAIM']._serialized_options = b'\202\347\260*\006sender\212\347\260*\025hyperlane/v1/MsgClaim'
  _globals['_MSGCREATEMERKLETREEHOOK'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATEMERKLETREEHOOK'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEMERKLETREEHOOK'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MSGCREATEMERKLETREEHOOK'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMERKLETREEHOOK']._loaded_options = None
  _globals['_MSGCREATEMERKLETREEHOOK']._serialized_options = b'\202\347\260*\005owner\212\347\260*$hyperlane/v1/MsgCreateMerkleTreeHook'
  _globals['_MSGCREATEMERKLETREEHOOKRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEMERKLETREEHOOKRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATENOOPHOOK'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATENOOPHOOK'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATENOOPHOOK']._loaded_options = None
  _globals['_MSGCREATENOOPHOOK']._serialized_options = b'\202\347\260*\005owner\212\347\260*$hyperlane/v1/MsgCreateMerkleTreeHook'
  _globals['_MSGCREATENOOPHOOKRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATENOOPHOOKRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEIGP']._serialized_start=248
  _globals['_MSGCREATEIGP']._serialized_end=393
  _globals['_MSGCREATEIGPRESPONSE']._serialized_start=395
  _globals['_MSGCREATEIGPRESPONSE']._serialized_end=502
  _globals['_MSGSETIGPOWNER']._serialized_start=505
  _globals['_MSGSETIGPOWNER']._serialized_end=781
  _globals['_MSGSETIGPOWNERRESPONSE']._serialized_start=783
  _globals['_MSGSETIGPOWNERRESPONSE']._serialized_end=807
  _globals['_MSGSETDESTINATIONGASCONFIG']._serialized_start=810
  _globals['_MSGSETDESTINATIONGASCONFIG']._serialized_end=1143
  _globals['_MSGSETDESTINATIONGASCONFIGRESPONSE']._serialized_start=1145
  _globals['_MSGSETDESTINATIONGASCONFIGRESPONSE']._serialized_end=1181
  _globals['_MSGPAYFORGAS']._serialized_start=1184
  _globals['_MSGPAYFORGAS']._serialized_end=1652
  _globals['_MSGPAYFORGASRESPONSE']._serialized_start=1654
  _globals['_MSGPAYFORGASRESPONSE']._serialized_end=1676
  _globals['_MSGCLAIM']._serialized_start=1679
  _globals['_MSGCLAIM']._serialized_end=1870
  _globals['_MSGCLAIMRESPONSE']._serialized_start=1872
  _globals['_MSGCLAIMRESPONSE']._serialized_end=1890
  _globals['_MSGCREATEMERKLETREEHOOK']._serialized_start=1893
  _globals['_MSGCREATEMERKLETREEHOOK']._serialized_end=2119
  _globals['_MSGCREATEMERKLETREEHOOKRESPONSE']._serialized_start=2121
  _globals['_MSGCREATEMERKLETREEHOOKRESPONSE']._serialized_end=2239
  _globals['_MSGCREATENOOPHOOK']._serialized_start=2241
  _globals['_MSGCREATENOOPHOOK']._serialized_end=2361
  _globals['_MSGCREATENOOPHOOKRESPONSE']._serialized_start=2363
  _globals['_MSGCREATENOOPHOOKRESPONSE']._serialized_end=2475
  _globals['_MSG']._serialized_start=2478
  _globals['_MSG']._serialized_end=3382
# @@protoc_insertion_point(module_scope)
