# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+hyperlane/core/post_dispatch/v1/types.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xac\x02\n\x16InterchainGasPaymaster\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x14\n\x05\x64\x65nom\x18\x03 \x01(\tR\x05\x64\x65nom\x12w\n\x0e\x63laimable_fees\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01R\rclaimableFees\"\xc8\x01\n\x14\x44\x65stinationGasConfig\x12#\n\rremote_domain\x18\x01 \x01(\rR\x0cremoteDomain\x12I\n\ngas_oracle\x18\x02 \x01(\x0b\x32*.hyperlane.core.post_dispatch.v1.GasOracleR\tgasOracle\x12@\n\x0cgas_overhead\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x0bgasOverhead\"\x96\x01\n\tGasOracle\x12M\n\x13token_exchange_rate\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x11tokenExchangeRate\x12:\n\tgas_price\x18\x02 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasPrice\"\xb4\x02\n\x0eMerkleTreeHook\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12\x62\n\nmailbox_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12.\n\x05owner\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x39\n\x04tree\x18\x04 \x01(\x0b\x32%.hyperlane.core.post_dispatch.v1.TreeR\x04tree\"4\n\x04Tree\x12\x16\n\x06\x62ranch\x18\x01 \x03(\x0cR\x06\x62ranch\x12\x14\n\x05\x63ount\x18\x02 \x01(\rR\x05\x63ount\"\x8f\x01\n\x08NoopHook\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05ownerB\x97\x02\n#com.hyperlane.core.post_dispatch.v1B\nTypesProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\nTypesProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['id']._loaded_options = None
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['owner']._loaded_options = None
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['claimable_fees']._loaded_options = None
  _globals['_INTERCHAINGASPAYMASTER'].fields_by_name['claimable_fees']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _globals['_DESTINATIONGASCONFIG'].fields_by_name['gas_overhead']._loaded_options = None
  _globals['_DESTINATIONGASCONFIG'].fields_by_name['gas_overhead']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_GASORACLE'].fields_by_name['token_exchange_rate']._loaded_options = None
  _globals['_GASORACLE'].fields_by_name['token_exchange_rate']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_GASORACLE'].fields_by_name['gas_price']._loaded_options = None
  _globals['_GASORACLE'].fields_by_name['gas_price']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MERKLETREEHOOK'].fields_by_name['id']._loaded_options = None
  _globals['_MERKLETREEHOOK'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MERKLETREEHOOK'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MERKLETREEHOOK'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MERKLETREEHOOK'].fields_by_name['owner']._loaded_options = None
  _globals['_MERKLETREEHOOK'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_NOOPHOOK'].fields_by_name['id']._loaded_options = None
  _globals['_NOOPHOOK'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_NOOPHOOK'].fields_by_name['owner']._loaded_options = None
  _globals['_NOOPHOOK'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_INTERCHAINGASPAYMASTER']._serialized_start=181
  _globals['_INTERCHAINGASPAYMASTER']._serialized_end=481
  _globals['_DESTINATIONGASCONFIG']._serialized_start=484
  _globals['_DESTINATIONGASCONFIG']._serialized_end=684
  _globals['_GASORACLE']._serialized_start=687
  _globals['_GASORACLE']._serialized_end=837
  _globals['_MERKLETREEHOOK']._serialized_start=840
  _globals['_MERKLETREEHOOK']._serialized_end=1148
  _globals['_TREE']._serialized_start=1150
  _globals['_TREE']._serialized_end=1202
  _globals['_NOOPHOOK']._serialized_start=1205
  _globals['_NOOPHOOK']._serialized_end=1348
# @@protoc_insertion_point(module_scope)
