# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ahyperlane/core/v1/tx.proto\x12\x11hyperlane.core.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xcb\x03\n\x10MsgCreateMailbox\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12!\n\x0clocal_domain\x18\x02 \x01(\rR\x0blocalDomain\x12\x64\n\x0b\x64\x65\x66\x61ult_ism\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\ndefaultIsm\x12\x66\n\x0c\x64\x65\x66\x61ult_hook\x18\x04 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0b\x64\x65\x66\x61ultHook\x12h\n\rrequired_hook\x18\x05 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0crequiredHook:,\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\x1dhyperlane/v1/MsgCreateMailbox\"o\n\x18MsgCreateMailboxResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xec\x04\n\rMsgSetMailbox\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x62\n\nmailbox_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x64\n\x0b\x64\x65\x66\x61ult_ism\x18\x03 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\ndefaultIsm\x12\x66\n\x0c\x64\x65\x66\x61ult_hook\x18\x04 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0b\x64\x65\x66\x61ultHook\x12h\n\rrequired_hook\x18\x05 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0crequiredHook\x12\x35\n\tnew_owner\x18\x06 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08newOwner\x12-\n\x12renounce_ownership\x18\x07 \x01(\x08R\x11renounceOwnership:)\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\x1ahyperlane/v1/MsgSetMailbox\"\x17\n\x15MsgSetMailboxResponse\"\x92\x02\n\x11MsgProcessMessage\x12\x62\n\nmailbox_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x32\n\x07relayer\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07relayer\x12\x1a\n\x08metadata\x18\x03 \x01(\tR\x08metadata\x12\x18\n\x07message\x18\x04 \x01(\tR\x07message:/\x82\xe7\xb0*\x07relayer\x8a\xe7\xb0*\x1ehyperlane/v1/MsgProcessMessage\"\x1b\n\x19MsgProcessMessageResponse2\xaf\x02\n\x03Msg\x12\x61\n\rCreateMailbox\x12#.hyperlane.core.v1.MsgCreateMailbox\x1a+.hyperlane.core.v1.MsgCreateMailboxResponse\x12X\n\nSetMailbox\x12 .hyperlane.core.v1.MsgSetMailbox\x1a(.hyperlane.core.v1.MsgSetMailboxResponse\x12\x64\n\x0eProcessMessage\x12$.hyperlane.core.v1.MsgProcessMessage\x1a,.hyperlane.core.v1.MsgProcessMessageResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xc0\x01\n\x15\x63om.hyperlane.core.v1B\x07TxProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\xa2\x02\x03HCX\xaa\x02\x11Hyperlane.Core.V1\xca\x02\x11Hyperlane\\Core\\V1\xe2\x02\x1dHyperlane\\Core\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.core.v1B\007TxProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\242\002\003HCX\252\002\021Hyperlane.Core.V1\312\002\021Hyperlane\\Core\\V1\342\002\035Hyperlane\\Core\\V1\\GPBMetadata\352\002\023Hyperlane::Core::V1'
  _globals['_MSGCREATEMAILBOX'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATEMAILBOX'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEMAILBOX'].fields_by_name['default_ism']._loaded_options = None
  _globals['_MSGCREATEMAILBOX'].fields_by_name['default_ism']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMAILBOX'].fields_by_name['default_hook']._loaded_options = None
  _globals['_MSGCREATEMAILBOX'].fields_by_name['default_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMAILBOX'].fields_by_name['required_hook']._loaded_options = None
  _globals['_MSGCREATEMAILBOX'].fields_by_name['required_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMAILBOX']._loaded_options = None
  _globals['_MSGCREATEMAILBOX']._serialized_options = b'\202\347\260*\005owner\212\347\260*\035hyperlane/v1/MsgCreateMailbox'
  _globals['_MSGCREATEMAILBOXRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEMAILBOXRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMAILBOX'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['default_ism']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['default_ism']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['default_hook']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['default_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['required_hook']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['required_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETMAILBOX'].fields_by_name['new_owner']._loaded_options = None
  _globals['_MSGSETMAILBOX'].fields_by_name['new_owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMAILBOX']._loaded_options = None
  _globals['_MSGSETMAILBOX']._serialized_options = b'\202\347\260*\005owner\212\347\260*\032hyperlane/v1/MsgSetMailbox'
  _globals['_MSGPROCESSMESSAGE'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MSGPROCESSMESSAGE'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGPROCESSMESSAGE'].fields_by_name['relayer']._loaded_options = None
  _globals['_MSGPROCESSMESSAGE'].fields_by_name['relayer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGPROCESSMESSAGE']._loaded_options = None
  _globals['_MSGPROCESSMESSAGE']._serialized_options = b'\202\347\260*\007relayer\212\347\260*\036hyperlane/v1/MsgProcessMessage'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEMAILBOX']._serialized_start=143
  _globals['_MSGCREATEMAILBOX']._serialized_end=602
  _globals['_MSGCREATEMAILBOXRESPONSE']._serialized_start=604
  _globals['_MSGCREATEMAILBOXRESPONSE']._serialized_end=715
  _globals['_MSGSETMAILBOX']._serialized_start=718
  _globals['_MSGSETMAILBOX']._serialized_end=1338
  _globals['_MSGSETMAILBOXRESPONSE']._serialized_start=1340
  _globals['_MSGSETMAILBOXRESPONSE']._serialized_end=1363
  _globals['_MSGPROCESSMESSAGE']._serialized_start=1366
  _globals['_MSGPROCESSMESSAGE']._serialized_end=1640
  _globals['_MSGPROCESSMESSAGERESPONSE']._serialized_start=1642
  _globals['_MSGPROCESSMESSAGERESPONSE']._serialized_end=1669
  _globals['_MSG']._serialized_start=1672
  _globals['_MSG']._serialized_end=1975
# @@protoc_insertion_point(module_scope)
