# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from hyperlane.core.post_dispatch.v1 import types_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_types__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+hyperlane/core/post_dispatch/v1/query.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a+hyperlane/core/post_dispatch/v1/types.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"Z\n\x10QueryIgpsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb4\x01\n\x11QueryIgpsResponse\x12V\n\x04igps\x18\x01 \x03(\x0b\x32\x37.hyperlane.core.post_dispatch.v1.InterchainGasPaymasterB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x04igps\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"!\n\x0fQueryIgpRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"h\n\x10QueryIgpResponse\x12T\n\x03igp\x18\x01 \x01(\x0b\x32\x37.hyperlane.core.post_dispatch.v1.InterchainGasPaymasterB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x03igp\"{\n!QueryDestinationGasConfigsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xdc\x01\n\"QueryDestinationGasConfigsResponse\x12m\n\x17\x64\x65stination_gas_configs\x18\x01 \x03(\x0b\x32\x35.hyperlane.core.post_dispatch.v1.DestinationGasConfigR\x15\x64\x65stinationGasConfigs\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x80\x01\n\x1bQueryQuoteGasPaymentRequest\x12\x15\n\x06igp_id\x18\x01 \x01(\tR\x05igpId\x12-\n\x12\x64\x65stination_domain\x18\x02 \x01(\tR\x11\x64\x65stinationDomain\x12\x1b\n\tgas_limit\x18\x03 \x01(\tR\x08gasLimit\"\x91\x01\n\x1cQueryQuoteGasPaymentResponse\x12q\n\x0bgas_payment\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01R\ngasPayment\"e\n\x1bQueryMerkleTreeHooksRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xde\x01\n\x1cQueryMerkleTreeHooksResponse\x12u\n\x11merkle_tree_hooks\x18\x01 \x03(\x0b\x32>.hyperlane.core.post_dispatch.v1.WrappedMerkleTreeHookResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0fmerkleTreeHooks\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\",\n\x1aQueryMerkleTreeHookRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x92\x01\n\x1bQueryMerkleTreeHookResponse\x12s\n\x10merkle_tree_hook\x18\x01 \x01(\x0b\x32>.hyperlane.core.post_dispatch.v1.WrappedMerkleTreeHookResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0emerkleTreeHook\"\xb4\x01\n\x1dWrappedMerkleTreeHookResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x1d\n\nmailbox_id\x18\x03 \x01(\tR\tmailboxId\x12N\n\x0bmerkle_tree\x18\x04 \x01(\x0b\x32-.hyperlane.core.post_dispatch.v1.TreeResponseR\nmerkleTree\"N\n\x0cTreeResponse\x12\x14\n\x05leafs\x18\x01 \x03(\x0cR\x05leafs\x12\x14\n\x05\x63ount\x18\x02 \x01(\rR\x05\x63ount\x12\x12\n\x04root\x18\x03 \x01(\x0cR\x04root\"&\n\x14QueryNoopHookRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"_\n\x15QueryNoopHookResponse\x12\x46\n\tnoop_hook\x18\x01 \x01(\x0b\x32).hyperlane.core.post_dispatch.v1.NoopHookR\x08noopHook\"_\n\x15QueryNoopHooksRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb6\x01\n\x16QueryNoopHooksResponse\x12S\n\nnoop_hooks\x18\x01 \x03(\x0b\x32).hyperlane.core.post_dispatch.v1.NoopHookB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\tnoopHooks\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination2\xff\n\n\x05Query\x12\x89\x01\n\x04Igps\x12\x31.hyperlane.core.post_dispatch.v1.QueryIgpsRequest\x1a\x32.hyperlane.core.post_dispatch.v1.QueryIgpsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/hyperlane/v1/igps\x12\x8b\x01\n\x03Igp\x12\x30.hyperlane.core.post_dispatch.v1.QueryIgpRequest\x1a\x31.hyperlane.core.post_dispatch.v1.QueryIgpResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/hyperlane/v1/igps/{id}\x12\xd9\x01\n\x15\x44\x65stinationGasConfigs\x12\x42.hyperlane.core.post_dispatch.v1.QueryDestinationGasConfigsRequest\x1a\x43.hyperlane.core.post_dispatch.v1.QueryDestinationGasConfigsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//hyperlane/v1/igps/{id}/destination_gas_configs\x12\xc5\x01\n\x0fQuoteGasPayment\x12<.hyperlane.core.post_dispatch.v1.QueryQuoteGasPaymentRequest\x1a=.hyperlane.core.post_dispatch.v1.QueryQuoteGasPaymentResponse\"5\x82\xd3\xe4\x93\x02/\x12-/hyperlane/v1/igps/{igp_id}/quote_gas_payment\x12\xb7\x01\n\x0fMerkleTreeHooks\x12<.hyperlane.core.post_dispatch.v1.QueryMerkleTreeHooksRequest\x1a=.hyperlane.core.post_dispatch.v1.QueryMerkleTreeHooksResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/hyperlane/v1/merkle_tree_hooks\x12\xb9\x01\n\x0eMerkleTreeHook\x12;.hyperlane.core.post_dispatch.v1.QueryMerkleTreeHookRequest\x1a<.hyperlane.core.post_dispatch.v1.QueryMerkleTreeHookResponse\",\x82\xd3\xe4\x93\x02&\x12$/hyperlane/v1/merkle_tree_hooks/{id}\x12\x9e\x01\n\tNoopHooks\x12\x36.hyperlane.core.post_dispatch.v1.QueryNoopHooksRequest\x1a\x37.hyperlane.core.post_dispatch.v1.QueryNoopHooksResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/hyperlane/v1/noop_hooks\x12\xa0\x01\n\x08NoopHook\x12\x35.hyperlane.core.post_dispatch.v1.QueryNoopHookRequest\x1a\x36.hyperlane.core.post_dispatch.v1.QueryNoopHookResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/hyperlane/v1/noop_hooks/{id}B\x97\x02\n#com.hyperlane.core.post_dispatch.v1B\nQueryProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\nQueryProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_QUERYIGPSRESPONSE'].fields_by_name['igps']._loaded_options = None
  _globals['_QUERYIGPSRESPONSE'].fields_by_name['igps']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYIGPRESPONSE'].fields_by_name['igp']._loaded_options = None
  _globals['_QUERYIGPRESPONSE'].fields_by_name['igp']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYQUOTEGASPAYMENTRESPONSE'].fields_by_name['gas_payment']._loaded_options = None
  _globals['_QUERYQUOTEGASPAYMENTRESPONSE'].fields_by_name['gas_payment']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _globals['_QUERYMERKLETREEHOOKSRESPONSE'].fields_by_name['merkle_tree_hooks']._loaded_options = None
  _globals['_QUERYMERKLETREEHOOKSRESPONSE'].fields_by_name['merkle_tree_hooks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYMERKLETREEHOOKRESPONSE'].fields_by_name['merkle_tree_hook']._loaded_options = None
  _globals['_QUERYMERKLETREEHOOKRESPONSE'].fields_by_name['merkle_tree_hook']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYNOOPHOOKSRESPONSE'].fields_by_name['noop_hooks']._loaded_options = None
  _globals['_QUERYNOOPHOOKSRESPONSE'].fields_by_name['noop_hooks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Igps']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Igps']._serialized_options = b'\202\323\344\223\002\024\022\022/hyperlane/v1/igps'
  _globals['_QUERY'].methods_by_name['Igp']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Igp']._serialized_options = b'\202\323\344\223\002\031\022\027/hyperlane/v1/igps/{id}'
  _globals['_QUERY'].methods_by_name['DestinationGasConfigs']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DestinationGasConfigs']._serialized_options = b'\202\323\344\223\0021\022//hyperlane/v1/igps/{id}/destination_gas_configs'
  _globals['_QUERY'].methods_by_name['QuoteGasPayment']._loaded_options = None
  _globals['_QUERY'].methods_by_name['QuoteGasPayment']._serialized_options = b'\202\323\344\223\002/\022-/hyperlane/v1/igps/{igp_id}/quote_gas_payment'
  _globals['_QUERY'].methods_by_name['MerkleTreeHooks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MerkleTreeHooks']._serialized_options = b'\202\323\344\223\002!\022\037/hyperlane/v1/merkle_tree_hooks'
  _globals['_QUERY'].methods_by_name['MerkleTreeHook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MerkleTreeHook']._serialized_options = b'\202\323\344\223\002&\022$/hyperlane/v1/merkle_tree_hooks/{id}'
  _globals['_QUERY'].methods_by_name['NoopHooks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NoopHooks']._serialized_options = b'\202\323\344\223\002\032\022\030/hyperlane/v1/noop_hooks'
  _globals['_QUERY'].methods_by_name['NoopHook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NoopHook']._serialized_options = b'\202\323\344\223\002\037\022\035/hyperlane/v1/noop_hooks/{id}'
  _globals['_QUERYIGPSREQUEST']._serialized_start=272
  _globals['_QUERYIGPSREQUEST']._serialized_end=362
  _globals['_QUERYIGPSRESPONSE']._serialized_start=365
  _globals['_QUERYIGPSRESPONSE']._serialized_end=545
  _globals['_QUERYIGPREQUEST']._serialized_start=547
  _globals['_QUERYIGPREQUEST']._serialized_end=580
  _globals['_QUERYIGPRESPONSE']._serialized_start=582
  _globals['_QUERYIGPRESPONSE']._serialized_end=686
  _globals['_QUERYDESTINATIONGASCONFIGSREQUEST']._serialized_start=688
  _globals['_QUERYDESTINATIONGASCONFIGSREQUEST']._serialized_end=811
  _globals['_QUERYDESTINATIONGASCONFIGSRESPONSE']._serialized_start=814
  _globals['_QUERYDESTINATIONGASCONFIGSRESPONSE']._serialized_end=1034
  _globals['_QUERYQUOTEGASPAYMENTREQUEST']._serialized_start=1037
  _globals['_QUERYQUOTEGASPAYMENTREQUEST']._serialized_end=1165
  _globals['_QUERYQUOTEGASPAYMENTRESPONSE']._serialized_start=1168
  _globals['_QUERYQUOTEGASPAYMENTRESPONSE']._serialized_end=1313
  _globals['_QUERYMERKLETREEHOOKSREQUEST']._serialized_start=1315
  _globals['_QUERYMERKLETREEHOOKSREQUEST']._serialized_end=1416
  _globals['_QUERYMERKLETREEHOOKSRESPONSE']._serialized_start=1419
  _globals['_QUERYMERKLETREEHOOKSRESPONSE']._serialized_end=1641
  _globals['_QUERYMERKLETREEHOOKREQUEST']._serialized_start=1643
  _globals['_QUERYMERKLETREEHOOKREQUEST']._serialized_end=1687
  _globals['_QUERYMERKLETREEHOOKRESPONSE']._serialized_start=1690
  _globals['_QUERYMERKLETREEHOOKRESPONSE']._serialized_end=1836
  _globals['_WRAPPEDMERKLETREEHOOKRESPONSE']._serialized_start=1839
  _globals['_WRAPPEDMERKLETREEHOOKRESPONSE']._serialized_end=2019
  _globals['_TREERESPONSE']._serialized_start=2021
  _globals['_TREERESPONSE']._serialized_end=2099
  _globals['_QUERYNOOPHOOKREQUEST']._serialized_start=2101
  _globals['_QUERYNOOPHOOKREQUEST']._serialized_end=2139
  _globals['_QUERYNOOPHOOKRESPONSE']._serialized_start=2141
  _globals['_QUERYNOOPHOOKRESPONSE']._serialized_end=2236
  _globals['_QUERYNOOPHOOKSREQUEST']._serialized_start=2238
  _globals['_QUERYNOOPHOOKSREQUEST']._serialized_end=2333
  _globals['_QUERYNOOPHOOKSRESPONSE']._serialized_start=2336
  _globals['_QUERYNOOPHOOKSRESPONSE']._serialized_end=2518
  _globals['_QUERY']._serialized_start=2521
  _globals['_QUERY']._serialized_end=3928
# @@protoc_insertion_point(module_scope)
