# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1hyperlane/core/interchain_security/v1/types.proto\x12%hyperlane.core.interchain_security.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"|\n\x05Route\x12U\n\x03ism\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x03ism\x12\x16\n\x06\x64omain\x18\x02 \x01(\rR\x06\x64omain:\x04\x88\xa0\x1f\x00\"\xae\x02\n\nRoutingISM\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12J\n\x06routes\x18\x03 \x03(\x0b\x32,.hyperlane.core.interchain_security.v1.RouteB\x04\xc8\xde\x1f\x00R\x06routes:O\x88\xa0\x1f\x00\xca\xb4-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule\"\xaa\x02\n\x14MessageIdMultisigISM\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1e\n\nvalidators\x18\x03 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x04 \x01(\rR\tthreshold:O\x88\xa0\x1f\x00\xca\xb4-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule\"\xab\x02\n\x15MerkleRootMultisigISM\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1e\n\nvalidators\x18\x03 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x04 \x01(\rR\tthreshold:O\x88\xa0\x1f\x00\xca\xb4-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule\"\xdf\x01\n\x07NoopISM\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner:O\x88\xa0\x1f\x00\xca\xb4-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModuleB\xbb\x02\n)com.hyperlane.core.interchain_security.v1B\nTypesProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\nTypesProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_ROUTE'].fields_by_name['ism']._loaded_options = None
  _globals['_ROUTE'].fields_by_name['ism']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_ROUTE']._loaded_options = None
  _globals['_ROUTE']._serialized_options = b'\210\240\037\000'
  _globals['_ROUTINGISM'].fields_by_name['id']._loaded_options = None
  _globals['_ROUTINGISM'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_ROUTINGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_ROUTINGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_ROUTINGISM'].fields_by_name['routes']._loaded_options = None
  _globals['_ROUTINGISM'].fields_by_name['routes']._serialized_options = b'\310\336\037\000'
  _globals['_ROUTINGISM']._loaded_options = None
  _globals['_ROUTINGISM']._serialized_options = b'\210\240\037\000\312\264-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule'
  _globals['_MESSAGEIDMULTISIGISM'].fields_by_name['id']._loaded_options = None
  _globals['_MESSAGEIDMULTISIGISM'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MESSAGEIDMULTISIGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_MESSAGEIDMULTISIGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MESSAGEIDMULTISIGISM']._loaded_options = None
  _globals['_MESSAGEIDMULTISIGISM']._serialized_options = b'\210\240\037\000\312\264-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule'
  _globals['_MERKLEROOTMULTISIGISM'].fields_by_name['id']._loaded_options = None
  _globals['_MERKLEROOTMULTISIGISM'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MERKLEROOTMULTISIGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_MERKLEROOTMULTISIGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MERKLEROOTMULTISIGISM']._loaded_options = None
  _globals['_MERKLEROOTMULTISIGISM']._serialized_options = b'\210\240\037\000\312\264-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule'
  _globals['_NOOPISM'].fields_by_name['id']._loaded_options = None
  _globals['_NOOPISM'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_NOOPISM'].fields_by_name['owner']._loaded_options = None
  _globals['_NOOPISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_NOOPISM']._loaded_options = None
  _globals['_NOOPISM']._serialized_options = b'\210\240\037\000\312\264-Ghyperlane.core.interchain_security.v1.HyperlaneInterchainSecurityModule'
  _globals['_ROUTE']._serialized_start=141
  _globals['_ROUTE']._serialized_end=265
  _globals['_ROUTINGISM']._serialized_start=268
  _globals['_ROUTINGISM']._serialized_end=570
  _globals['_MESSAGEIDMULTISIGISM']._serialized_start=573
  _globals['_MESSAGEIDMULTISIGISM']._serialized_end=871
  _globals['_MERKLEROOTMULTISIGISM']._serialized_start=874
  _globals['_MERKLEROOTMULTISIGISM']._serialized_end=1173
  _globals['_NOOPISM']._serialized_start=1176
  _globals['_NOOPISM']._serialized_end=1399
# @@protoc_insertion_point(module_scope)
