# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/downtimedetector/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.downtimedetector.v1beta1 import genesis_pb2 as injective_dot_downtimedetector_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.injective.downtimedetector.v1beta1 import downtime_duration_pb2 as injective_dot_downtimedetector_dot_v1beta1_dot_downtime__duration__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.injective/downtimedetector/v1beta1/query.proto\x12\"injective.downtimedetector.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x30injective/downtimedetector/v1beta1/genesis.proto\x1a:injective/downtimedetector/v1beta1/downtime_duration.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x01\n%RecoveredSinceDowntimeOfLengthRequest\x12]\n\x08\x64owntime\x18\x01 \x01(\x0e\x32,.injective.downtimedetector.v1beta1.DowntimeB\x13\xf2\xde\x1f\x0fyaml:\"downtime\"R\x08\x64owntime\x12[\n\x08recovery\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB$\xc8\xde\x1f\x00\xf2\xde\x1f\x18yaml:\"recovery_duration\"\x98\xdf\x1f\x01R\x08recovery\"_\n&RecoveredSinceDowntimeOfLengthResponse\x12\x35\n\x16successfully_recovered\x18\x01 \x01(\x08R\x15successfullyRecovered2\x91\x02\n\x05Query\x12\x87\x02\n\x1eRecoveredSinceDowntimeOfLength\x12I.injective.downtimedetector.v1beta1.RecoveredSinceDowntimeOfLengthRequest\x1aJ.injective.downtimedetector.v1beta1.RecoveredSinceDowntimeOfLengthResponse\"N\x82\xd3\xe4\x93\x02H\"C/injective/downtime-detector/v1beta1/RecoveredSinceDowntimeOfLength:\x01*B\xb7\x02\n&com.injective.downtimedetector.v1beta1B\nQueryProtoP\x01ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\xa2\x02\x03IDX\xaa\x02\"Injective.Downtimedetector.V1beta1\xca\x02\"Injective\\Downtimedetector\\V1beta1\xe2\x02.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\xea\x02$Injective::Downtimedetector::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.downtimedetector.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.injective.downtimedetector.v1beta1B\nQueryProtoP\001ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\242\002\003IDX\252\002\"Injective.Downtimedetector.V1beta1\312\002\"Injective\\Downtimedetector\\V1beta1\342\002.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\352\002$Injective::Downtimedetector::V1beta1'
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST'].fields_by_name['downtime']._loaded_options = None
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST'].fields_by_name['downtime']._serialized_options = b'\362\336\037\017yaml:\"downtime\"'
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST'].fields_by_name['recovery']._loaded_options = None
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST'].fields_by_name['recovery']._serialized_options = b'\310\336\037\000\362\336\037\030yaml:\"recovery_duration\"\230\337\037\001'
  _globals['_QUERY'].methods_by_name['RecoveredSinceDowntimeOfLength']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RecoveredSinceDowntimeOfLength']._serialized_options = b'\202\323\344\223\002H\"C/injective/downtime-detector/v1beta1/RecoveredSinceDowntimeOfLength:\001*'
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST']._serialized_start=444
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST']._serialized_end=671
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHRESPONSE']._serialized_start=673
  _globals['_RECOVEREDSINCEDOWNTIMEOFLENGTHRESPONSE']._serialized_end=768
  _globals['_QUERY']._serialized_start=771
  _globals['_QUERY']._serialized_end=1044
# @@protoc_insertion_point(module_scope)
