# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from hyperlane.core.v1 import types_pb2 as hyperlane_dot_core_dot_v1_dot_types__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhyperlane/core/v1/query.proto\x12\x11hyperlane.core.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1dhyperlane/core/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"_\n\x15QueryMailboxesRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xa6\x01\n\x16QueryMailboxesResponse\x12\x43\n\tmailboxes\x18\x01 \x03(\x0b\x32\x1a.hyperlane.core.v1.MailboxB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\tmailboxes\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"%\n\x13QueryMailboxRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"W\n\x14QueryMailboxResponse\x12?\n\x07mailbox\x18\x01 \x01(\x0b\x32\x1a.hyperlane.core.v1.MailboxB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07mailbox\"F\n\x15QueryDeliveredRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nmessage_id\x18\x02 \x01(\tR\tmessageId\"6\n\x16QueryDeliveredResponse\x12\x1c\n\tdelivered\x18\x01 \x01(\x08R\tdelivered\"8\n\x18QueryRecipientIsmRequest\x12\x1c\n\trecipient\x18\x01 \x01(\tR\trecipient\"2\n\x19QueryRecipientIsmResponse\x12\x15\n\x06ism_id\x18\x01 \x01(\tR\x05ismId\"\x84\x01\n\x18QueryVerifyDryRunRequest\x12\x15\n\x06ism_id\x18\x01 \x01(\tR\x05ismId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x1a\n\x08metadata\x18\x03 \x01(\tR\x08metadata\x12\x1b\n\tgas_limit\x18\x04 \x01(\tR\x08gasLimit\"7\n\x19QueryVerifyDryRunResponse\x12\x1a\n\x08verified\x18\x01 \x01(\x08R\x08verified\"\x15\n\x13QueryRegisteredISMs\"/\n\x1bQueryRegisteredISMsResponse\x12\x10\n\x03ids\x18\x01 \x03(\rR\x03ids\"\x16\n\x14QueryRegisteredHooks\"0\n\x1cQueryRegisteredHooksResponse\x12\x10\n\x03ids\x18\x01 \x03(\rR\x03ids\"\x15\n\x13QueryRegisteredApps\"/\n\x1bQueryRegisteredAppsResponse\x12\x10\n\x03ids\x18\x01 \x03(\rR\x03ids2\x97\t\n\x05Query\x12\x81\x01\n\tMailboxes\x12(.hyperlane.core.v1.QueryMailboxesRequest\x1a).hyperlane.core.v1.QueryMailboxesResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/hyperlane/v1/mailboxes\x12\x80\x01\n\x07Mailbox\x12&.hyperlane.core.v1.QueryMailboxRequest\x1a\'.hyperlane.core.v1.QueryMailboxResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/hyperlane/v1/mailboxes/{id}\x12\x9d\x01\n\tDelivered\x12(.hyperlane.core.v1.QueryDeliveredRequest\x1a).hyperlane.core.v1.QueryDeliveredResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/hyperlane/v1/mailboxes/{id}/delivered/{message_id}\x12\x9a\x01\n\x0cRecipientIsm\x12+.hyperlane.core.v1.QueryRecipientIsmRequest\x1a,.hyperlane.core.v1.QueryRecipientIsmResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/hyperlane/v1/recipient_ism/{recipient}\x12\x8f\x01\n\x0cVerifyDryRun\x12+.hyperlane.core.v1.QueryVerifyDryRunRequest\x1a,.hyperlane.core.v1.QueryVerifyDryRunResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/hyperlane/v1/verify_dry_run\x12\x8f\x01\n\x0eRegisteredISMs\x12&.hyperlane.core.v1.QueryRegisteredISMs\x1a..hyperlane.core.v1.QueryRegisteredISMsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/hyperlane/v1/registered_isms\x12\x93\x01\n\x0fRegisteredHooks\x12\'.hyperlane.core.v1.QueryRegisteredHooks\x1a/.hyperlane.core.v1.QueryRegisteredHooksResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/hyperlane/v1/registered_hooks\x12\x8f\x01\n\x0eRegisteredApps\x12&.hyperlane.core.v1.QueryRegisteredApps\x1a..hyperlane.core.v1.QueryRegisteredAppsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/hyperlane/v1/registered_appsB\xc3\x01\n\x15\x63om.hyperlane.core.v1B\nQueryProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\xa2\x02\x03HCX\xaa\x02\x11Hyperlane.Core.V1\xca\x02\x11Hyperlane\\Core\\V1\xe2\x02\x1dHyperlane\\Core\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.core.v1B\nQueryProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\242\002\003HCX\252\002\021Hyperlane.Core.V1\312\002\021Hyperlane\\Core\\V1\342\002\035Hyperlane\\Core\\V1\\GPBMetadata\352\002\023Hyperlane::Core::V1'
  _globals['_QUERYMAILBOXESRESPONSE'].fields_by_name['mailboxes']._loaded_options = None
  _globals['_QUERYMAILBOXESRESPONSE'].fields_by_name['mailboxes']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYMAILBOXRESPONSE'].fields_by_name['mailbox']._loaded_options = None
  _globals['_QUERYMAILBOXRESPONSE'].fields_by_name['mailbox']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Mailboxes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Mailboxes']._serialized_options = b'\202\323\344\223\002\031\022\027/hyperlane/v1/mailboxes'
  _globals['_QUERY'].methods_by_name['Mailbox']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Mailbox']._serialized_options = b'\202\323\344\223\002\036\022\034/hyperlane/v1/mailboxes/{id}'
  _globals['_QUERY'].methods_by_name['Delivered']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Delivered']._serialized_options = b'\202\323\344\223\0025\0223/hyperlane/v1/mailboxes/{id}/delivered/{message_id}'
  _globals['_QUERY'].methods_by_name['RecipientIsm']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RecipientIsm']._serialized_options = b'\202\323\344\223\002)\022\'/hyperlane/v1/recipient_ism/{recipient}'
  _globals['_QUERY'].methods_by_name['VerifyDryRun']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VerifyDryRun']._serialized_options = b'\202\323\344\223\002\036\022\034/hyperlane/v1/verify_dry_run'
  _globals['_QUERY'].methods_by_name['RegisteredISMs']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RegisteredISMs']._serialized_options = b'\202\323\344\223\002\037\022\035/hyperlane/v1/registered_isms'
  _globals['_QUERY'].methods_by_name['RegisteredHooks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RegisteredHooks']._serialized_options = b'\202\323\344\223\002 \022\036/hyperlane/v1/registered_hooks'
  _globals['_QUERY'].methods_by_name['RegisteredApps']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RegisteredApps']._serialized_options = b'\202\323\344\223\002\037\022\035/hyperlane/v1/registered_apps'
  _globals['_QUERYMAILBOXESREQUEST']._serialized_start=198
  _globals['_QUERYMAILBOXESREQUEST']._serialized_end=293
  _globals['_QUERYMAILBOXESRESPONSE']._serialized_start=296
  _globals['_QUERYMAILBOXESRESPONSE']._serialized_end=462
  _globals['_QUERYMAILBOXREQUEST']._serialized_start=464
  _globals['_QUERYMAILBOXREQUEST']._serialized_end=501
  _globals['_QUERYMAILBOXRESPONSE']._serialized_start=503
  _globals['_QUERYMAILBOXRESPONSE']._serialized_end=590
  _globals['_QUERYDELIVEREDREQUEST']._serialized_start=592
  _globals['_QUERYDELIVEREDREQUEST']._serialized_end=662
  _globals['_QUERYDELIVEREDRESPONSE']._serialized_start=664
  _globals['_QUERYDELIVEREDRESPONSE']._serialized_end=718
  _globals['_QUERYRECIPIENTISMREQUEST']._serialized_start=720
  _globals['_QUERYRECIPIENTISMREQUEST']._serialized_end=776
  _globals['_QUERYRECIPIENTISMRESPONSE']._serialized_start=778
  _globals['_QUERYRECIPIENTISMRESPONSE']._serialized_end=828
  _globals['_QUERYVERIFYDRYRUNREQUEST']._serialized_start=831
  _globals['_QUERYVERIFYDRYRUNREQUEST']._serialized_end=963
  _globals['_QUERYVERIFYDRYRUNRESPONSE']._serialized_start=965
  _globals['_QUERYVERIFYDRYRUNRESPONSE']._serialized_end=1020
  _globals['_QUERYREGISTEREDISMS']._serialized_start=1022
  _globals['_QUERYREGISTEREDISMS']._serialized_end=1043
  _globals['_QUERYREGISTEREDISMSRESPONSE']._serialized_start=1045
  _globals['_QUERYREGISTEREDISMSRESPONSE']._serialized_end=1092
  _globals['_QUERYREGISTEREDHOOKS']._serialized_start=1094
  _globals['_QUERYREGISTEREDHOOKS']._serialized_end=1116
  _globals['_QUERYREGISTEREDHOOKSRESPONSE']._serialized_start=1118
  _globals['_QUERYREGISTEREDHOOKSRESPONSE']._serialized_end=1166
  _globals['_QUERYREGISTEREDAPPS']._serialized_start=1168
  _globals['_QUERYREGISTEREDAPPS']._serialized_end=1189
  _globals['_QUERYREGISTEREDAPPSRESPONSE']._serialized_start=1191
  _globals['_QUERYREGISTEREDAPPSRESPONSE']._serialized_end=1238
  _globals['_QUERY']._serialized_start=1241
  _globals['_QUERY']._serialized_end=2416
# @@protoc_insertion_point(module_scope)
