# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3hyperlane/core/interchain_security/v1/genesis.proto\x12%hyperlane.core.interchain_security.v1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\"\xce\x01\n\x0cGenesisState\x12(\n\x04isms\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyR\x04isms\x12\x93\x01\n\x1bvalidator_storage_locations\x18\x02 \x03(\x0b\x32M.hyperlane.core.interchain_security.v1.GenesisValidatorStorageLocationWrapperB\x04\xc8\xde\x1f\x00R\x19validatorStorageLocations\"\xb5\x01\n&GenesisValidatorStorageLocationWrapper\x12\x1d\n\nmailbox_id\x18\x01 \x01(\x04R\tmailboxId\x12+\n\x11validator_address\x18\x02 \x01(\tR\x10validatorAddress\x12\x14\n\x05index\x18\x03 \x01(\x04R\x05index\x12)\n\x10storage_location\x18\x04 \x01(\tR\x0fstorageLocationB\xbd\x02\n)com.hyperlane.core.interchain_security.v1B\x0cGenesisProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\014GenesisProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_GENESISSTATE'].fields_by_name['validator_storage_locations']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['validator_storage_locations']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=144
  _globals['_GENESISSTATE']._serialized_end=350
  _globals['_GENESISVALIDATORSTORAGELOCATIONWRAPPER']._serialized_start=353
  _globals['_GENESISVALIDATORSTORAGELOCATIONWRAPPER']._serialized_end=534
# @@protoc_insertion_point(module_scope)
