# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from hyperlane.warp.v1 import types_pb2 as hyperlane_dot_warp_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ahyperlane/warp/v1/tx.proto\x12\x11hyperlane.warp.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1dhyperlane/warp/v1/types.proto\"\x94\x02\n\x18MsgCreateCollateralToken\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12j\n\x0eorigin_mailbox\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x03 \x01(\tR\x0boriginDenom:9\x82\xe7\xb0*\x05owner\x8a\xe7\xb0**hyperlane/warp/v1/MsgCreateCollateralToken\"w\n MsgCreateCollateralTokenResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xef\x01\n\x17MsgCreateSyntheticToken\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12j\n\x0eorigin_mailbox\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox:8\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*)hyperlane/warp/v1/MsgCreateSyntheticToken\"\x9e\x02\n\x1dMsgCreateNativeSyntheticToken\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12j\n\x0eorigin_mailbox\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x03 \x01(\tR\x0boriginDenom:>\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*/hyperlane/warp/v1/MsgCreateNativeSyntheticToken\"v\n\x1fMsgCreateSyntheticTokenResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xf3\x02\n\x0bMsgSetToken\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12^\n\x08token_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x1b\n\tnew_owner\x18\x03 \x01(\tR\x08newOwner\x12Z\n\x06ism_id\x18\x04 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12-\n\x12renounce_ownership\x18\x07 \x01(\x08R\x11renounceOwnership:,\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\x1dhyperlane/warp/v1/MsgSetToken\"\x15\n\x13MsgSetTokenResponse\"\xa5\x02\n\x15MsgEnrollRemoteRouter\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12^\n\x08token_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x44\n\rremote_router\x18\x03 \x01(\x0b\x32\x1f.hyperlane.warp.v1.RemoteRouterR\x0cremoteRouter:6\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\'hyperlane/warp/v1/MsgEnrollRemoteRouter\"\x1f\n\x1dMsgEnrollRemoteRouterResponse\"\x88\x02\n\x15MsgUnrollRemoteRouter\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12^\n\x08token_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\'\n\x0freceiver_domain\x18\x03 \x01(\rR\x0ereceiverDomain:6\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\'hyperlane/warp/v1/MsgUnrollRemoteRouter\"\x1f\n\x1dMsgUnrollRemoteRouterResponse\"\xce\x05\n\x11MsgRemoteTransfer\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12^\n\x08token_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12-\n\x12\x64\x65stination_domain\x18\x03 \x01(\rR\x11\x64\x65stinationDomain\x12\x61\n\trecipient\x18\x04 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\trecipient\x12H\n\x06\x61mount\x18\x05 \x01(\tB0\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01R\x06\x61mount\x12i\n\x0e\x63ustom_hook_id\x18\x06 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0c\x63ustomHookId\x12:\n\tgas_limit\x18\x07 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasLimit\x12=\n\x07max_fee\x18\x08 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06maxFee\x12\x30\n\x14\x63ustom_hook_metadata\x18\t \x01(\tR\x12\x63ustomHookMetadata:3\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*#hyperlane/warp/v1/MsgRemoteTransfer\"\x7f\n\x19MsgRemoteTransferResponse\x12\x62\n\nmessage_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageId2\xa2\x06\n\x03Msg\x12y\n\x15\x43reateCollateralToken\x12+.hyperlane.warp.v1.MsgCreateCollateralToken\x1a\x33.hyperlane.warp.v1.MsgCreateCollateralTokenResponse\x12v\n\x14\x43reateSyntheticToken\x12*.hyperlane.warp.v1.MsgCreateSyntheticToken\x1a\x32.hyperlane.warp.v1.MsgCreateSyntheticTokenResponse\x12\x82\x01\n\x1a\x43reateNativeSyntheticToken\x12\x30.hyperlane.warp.v1.MsgCreateNativeSyntheticToken\x1a\x32.hyperlane.warp.v1.MsgCreateSyntheticTokenResponse\x12R\n\x08SetToken\x12\x1e.hyperlane.warp.v1.MsgSetToken\x1a&.hyperlane.warp.v1.MsgSetTokenResponse\x12p\n\x12\x45nrollRemoteRouter\x12(.hyperlane.warp.v1.MsgEnrollRemoteRouter\x1a\x30.hyperlane.warp.v1.MsgEnrollRemoteRouterResponse\x12p\n\x12UnrollRemoteRouter\x12(.hyperlane.warp.v1.MsgUnrollRemoteRouter\x1a\x30.hyperlane.warp.v1.MsgUnrollRemoteRouterResponse\x12\x64\n\x0eRemoteTransfer\x12$.hyperlane.warp.v1.MsgRemoteTransfer\x1a,.hyperlane.warp.v1.MsgRemoteTransferResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xc0\x01\n\x15\x63om.hyperlane.warp.v1B\x07TxProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\007TxProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_MSGCREATECOLLATERALTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATECOLLATERALTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATECOLLATERALTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_MSGCREATECOLLATERALTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATECOLLATERALTOKEN']._loaded_options = None
  _globals['_MSGCREATECOLLATERALTOKEN']._serialized_options = b'\202\347\260*\005owner\212\347\260**hyperlane/warp/v1/MsgCreateCollateralToken'
  _globals['_MSGCREATECOLLATERALTOKENRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATECOLLATERALTOKENRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATESYNTHETICTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATESYNTHETICTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_MSGCREATESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATESYNTHETICTOKEN']._loaded_options = None
  _globals['_MSGCREATESYNTHETICTOKEN']._serialized_options = b'\202\347\260*\005owner\212\347\260*)hyperlane/warp/v1/MsgCreateSyntheticToken'
  _globals['_MSGCREATENATIVESYNTHETICTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATENATIVESYNTHETICTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATENATIVESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_MSGCREATENATIVESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATENATIVESYNTHETICTOKEN']._loaded_options = None
  _globals['_MSGCREATENATIVESYNTHETICTOKEN']._serialized_options = b'\202\347\260*\005owner\212\347\260*/hyperlane/warp/v1/MsgCreateNativeSyntheticToken'
  _globals['_MSGCREATESYNTHETICTOKENRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATESYNTHETICTOKENRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGSETTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETTOKEN'].fields_by_name['token_id']._loaded_options = None
  _globals['_MSGSETTOKEN'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETTOKEN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_MSGSETTOKEN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETTOKEN']._loaded_options = None
  _globals['_MSGSETTOKEN']._serialized_options = b'\202\347\260*\005owner\212\347\260*\035hyperlane/warp/v1/MsgSetToken'
  _globals['_MSGENROLLREMOTEROUTER'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGENROLLREMOTEROUTER'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGENROLLREMOTEROUTER'].fields_by_name['token_id']._loaded_options = None
  _globals['_MSGENROLLREMOTEROUTER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGENROLLREMOTEROUTER']._loaded_options = None
  _globals['_MSGENROLLREMOTEROUTER']._serialized_options = b'\202\347\260*\005owner\212\347\260*\'hyperlane/warp/v1/MsgEnrollRemoteRouter'
  _globals['_MSGUNROLLREMOTEROUTER'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGUNROLLREMOTEROUTER'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUNROLLREMOTEROUTER'].fields_by_name['token_id']._loaded_options = None
  _globals['_MSGUNROLLREMOTEROUTER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGUNROLLREMOTEROUTER']._loaded_options = None
  _globals['_MSGUNROLLREMOTEROUTER']._serialized_options = b'\202\347\260*\005owner\212\347\260*\'hyperlane/warp/v1/MsgUnrollRemoteRouter'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['token_id']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['recipient']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['recipient']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['custom_hook_id']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['custom_hook_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['gas_limit']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['gas_limit']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['max_fee']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['max_fee']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGREMOTETRANSFER']._loaded_options = None
  _globals['_MSGREMOTETRANSFER']._serialized_options = b'\202\347\260*\006sender\212\347\260*#hyperlane/warp/v1/MsgRemoteTransfer'
  _globals['_MSGREMOTETRANSFERRESPONSE'].fields_by_name['message_id']._loaded_options = None
  _globals['_MSGREMOTETRANSFERRESPONSE'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATECOLLATERALTOKEN']._serialized_start=206
  _globals['_MSGCREATECOLLATERALTOKEN']._serialized_end=482
  _globals['_MSGCREATECOLLATERALTOKENRESPONSE']._serialized_start=484
  _globals['_MSGCREATECOLLATERALTOKENRESPONSE']._serialized_end=603
  _globals['_MSGCREATESYNTHETICTOKEN']._serialized_start=606
  _globals['_MSGCREATESYNTHETICTOKEN']._serialized_end=845
  _globals['_MSGCREATENATIVESYNTHETICTOKEN']._serialized_start=848
  _globals['_MSGCREATENATIVESYNTHETICTOKEN']._serialized_end=1134
  _globals['_MSGCREATESYNTHETICTOKENRESPONSE']._serialized_start=1136
  _globals['_MSGCREATESYNTHETICTOKENRESPONSE']._serialized_end=1254
  _globals['_MSGSETTOKEN']._serialized_start=1257
  _globals['_MSGSETTOKEN']._serialized_end=1628
  _globals['_MSGSETTOKENRESPONSE']._serialized_start=1630
  _globals['_MSGSETTOKENRESPONSE']._serialized_end=1651
  _globals['_MSGENROLLREMOTEROUTER']._serialized_start=1654
  _globals['_MSGENROLLREMOTEROUTER']._serialized_end=1947
  _globals['_MSGENROLLREMOTEROUTERRESPONSE']._serialized_start=1949
  _globals['_MSGENROLLREMOTEROUTERRESPONSE']._serialized_end=1980
  _globals['_MSGUNROLLREMOTEROUTER']._serialized_start=1983
  _globals['_MSGUNROLLREMOTEROUTER']._serialized_end=2247
  _globals['_MSGUNROLLREMOTEROUTERRESPONSE']._serialized_start=2249
  _globals['_MSGUNROLLREMOTEROUTERRESPONSE']._serialized_end=2280
  _globals['_MSGREMOTETRANSFER']._serialized_start=2283
  _globals['_MSGREMOTETRANSFER']._serialized_end=3001
  _globals['_MSGREMOTETRANSFERRESPONSE']._serialized_start=3003
  _globals['_MSGREMOTETRANSFERRESPONSE']._serialized_end=3130
  _globals['_MSG']._serialized_start=3133
  _globals['_MSG']._serialized_end=3935
# @@protoc_insertion_point(module_scope)
